import * as _playwright_test from '@playwright/test';
import { Page, APIRequestContext, Response, Locator, APIResponse, Fixtures, PlaywrightWorkerArgs, PlaywrightWorkerOptions, PlaywrightTestArgs, PlaywrightTestOptions, Browser, BrowserContext, FrameLocator, CDPSession } from '@playwright/test';
import * as mailosaur_lib_models from 'mailosaur/lib/models';
import MailosaurClient from 'mailosaur';
import { I18nPlaywrightFixture } from 'playwright-i18next-fixture';
import { TFunction } from 'i18next';
import * as playwright_core from 'playwright-core';
import { Protocol } from 'playwright-core/types/protocol';
import * as ts_toolbelt_out_Function_Curry from 'ts-toolbelt/out/Function/Curry';
import { Secret, TOTP } from 'otpauth';
interface InterceptMultipleResponsesParams {
  responseUrl: string;
  times: number;
  baseUrl: string;
  customPageContext: Page | undefined;
  timeout: number;
  responseStatus: number;
}
type GenericCallback = (...params: any[]) => Promise<unknown> | unknown;
interface ExecuteRecursivelyParams {
  callback: GenericCallback;
  condition: GenericCallback;
  timeout: number;
}
type ExecuteRecursively = (params: ExecuteRecursivelyParams) => Promise<void>;
interface VerifySuccessToastParams {
  message: string;
  closeAfterVerification: boolean;
}
interface VerifyToastParams {
  message: string;
  closeAfterVerification: boolean;
  toastType: "success" | "error";
}
type ConditionProps = Record<string, string>[];
type FilterProps = Record<string, ConditionProps>;
type ParamFilters = FilterProps[];
type BasicTypesInterface = Record<string, number | string | boolean>;
type ParamProps = Record<string, number | string | boolean | ParamFilters>;
type HttpMethods = "get" | "patch" | "post" | "put" | "delete";
interface ApiRequestProps {
  url: string;
  failOnStatusCode?: boolean;
  headers?: BasicTypesInterface;
  data?: Record<string, unknown>;
  method?: HttpMethods;
  params?: ParamProps;
}
interface WaitForPageLoadParams {
  visibilityTimeout: number;
  customPageContext: Page | undefined;
}
type ApiRequest = (props: ApiRequestProps & Record<string, unknown>) => Promise<APIResponse | undefined>;
interface FieldValue {
  field: string;
  value: string;
}
type VerifyFieldValue = (values: FieldValue | FieldValue[]) => Promise<void> | Promise<void[]>;
interface SelectOptionFromDropdownParams {
  selectValueContainer: string;
  selectMenu: string;
  value: string;
  options?: Partial<{
    visibilityTimeout: number;
    textAssertionTimeout: number;
    retryTimeout: number;
  }>;
}
interface SearchAndVerifyProps {
  searchTerm: string;
  countSelector: string;
  searchInputSelector?: string;
  countText: string;
}
declare class CustomCommands {
  page: Page;
  responses: string[];
  request: APIRequestContext;
  baseURL: string | undefined;
  constructor(page: Page, request: APIRequestContext, baseURL?: string | undefined);
  /**
   *
   * Command to wait until a response with URL responseUrl is found. Optionally,
   *
   * provide a base URL if it differs from the home URL of the project's host.
   *
   * @example 
   *
   *   // wait for 3 responses
   * 
   *   neetoPlaywrightUtilities.interceptMultipleResponses({
   *    responseUrl: "/login",
   *    times: 3,
   *    baseURL: "https://app.neetoauth.net",
   *   });
   * @endexample
  */
  interceptMultipleResponses: ({
    responseUrl,
    responseStatus,
    times,
    baseUrl,
    customPageContext,
    timeout
  }?: Partial<InterceptMultipleResponsesParams>) => Promise<Response[]>;
  private recursiveMethod;
  /**
   *
   * Command to check for a condition recursively until it's true, then execute a
   *
   * callback. This process will be repeated until the specified timeout.
   *
   * @example 
   *
   *  //checks if the URL contains /login for 5000 ms. If /login is found within this timeframe, the callback is executed.
   * 
   *  await neetoPlaywrightUtilities.executeRecursively({
   *    timeout: 5000,
   *    condition: () => this.page.url().match(/.*login/),
   *    callback: async () => {
   *     await expect("#locator").to.equal("Login");
   *    },
   *  });
   * @endexample
  */
  executeRecursively: ExecuteRecursively;
  /**
   * @deprecated Use verifyToast instead.
   */
  /**
   *
   * Command to assert the success toastr message. It takes the following parameters:
   *
   * closeAfterVerification(optional): Boolean to close the toast after verification. Default is true.
   *
   * message: Text that should be on toast.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.verifySuccessToast({
   *     message: "Toastr message",
   *     closeAfterVerification: false,
   *   });
   * @endexample
  */
  verifySuccessToast: ({
    message,
    closeAfterVerification
  }?: Partial<VerifySuccessToastParams>) => Promise<void>;
  /**
   *
   * Command to assert the toastr message. It takes the following parameters:
   *
   * closeAfterVerification(optional): Boolean to close the toast after verification. Default is true.
   *
   * message(optional): Text that should be on toast.
   *
   * toastType(optional): Type of toast. It takes either success or error as it's value. Default is success.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.verifyToast({
   *     message: "Toastr message",
   *     closeAfterVerification: false,
   *     toastType: "error"
   *   });
   * @endexample
  */
  verifyToast: ({
    message,
    toastType,
    closeAfterVerification
  }?: Partial<VerifyToastParams>) => Promise<void>;
  /**
   *
   * Command to reload and wait for the API responses.
   *
   * @example 
   *
   *   // wait for 3 responses after reloading
   *   await neetoPlaywrightUtilities.reloadAndWait(3);
   * @endexample
  */
  reloadAndWait: (requestCount: number, customPageContext?: Page, interceptMultipleResponsesProps?: Partial<Omit<InterceptMultipleResponsesParams, "times">>) => Promise<void>;
  /**
   *
   * Command to wait until the page has no loaders or spinners.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.waitForPageLoad({
   *     visiblityTimeout = 35_000,
   *     customPageContext,
   *   });
   * @endexample
  */
  waitForPageLoad: ({
    visibilityTimeout,
    customPageContext
  }?: Partial<WaitForPageLoadParams>) => Promise<void>;
  /**
   *
   * Command to send an API request.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.apiRequest({
   *     url: "/api/v1/tags",
   *     failOnStatusCode, // throws error for status codes other than 2xx and 3xx
   *     body, // request body
   *     method, // request method  "get" | "patch" | "post" | "put" | "delete"
   *     params, // request params
   *     headers, // aditional request headers
   *   });
   * @endexample
  */
  apiRequest: ApiRequest;
  /**
   *
   * Command to select an option from a select input. It retries until the select
   *
   * operation is completed. It takes the following parameters:
   *
   * selectValueContainer: is the selector for the select input container.
   *
   * selectMenu: is the selector for the select input menu.
   *
   * value: is the value to be selected.
   *
   * options: is an object with the following optional parameters:
   *
   * visiblityTimeout: is the time to wait for the select input to be visible. Default is 2000ms.
   *
   * textAssertionTimeout: is the time to wait for the selected value to be visible in the select input. Default is 1000ms.
   *
   * retryTimeout: is the time to wait until the select operation is completed. Default is 20000ms.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.selectOptionFromDropdown({
   *     selectValueContainer,
   *     selectMenu,
   *     value,
   *     options = {},
   *   });
   *   // or
   * 
   *   await neetoPlaywrightUtilities.selectOptionFromDropdown({
   *     selectValueContainer,
   *     selectMenu,
   *     value,
   *     options:{
   *       visiblityTimeout:200,
   *       textAssertionTimeout:1000,
   *       retryTimeout:20000
   *     },
   *   });
   * @endexample
  */
  selectOptionFromDropdown: ({
    selectValueContainer,
    selectMenu,
    value,
    options
  }: SelectOptionFromDropdownParams) => Promise<void>;
  /**
   *
   * Command to verify the value of a field. It can take either a single object or an array of objects, each representing a field and its expected value.
   *
   * @example 
   *
   * // verifyFieldValue with an array of field-value pairs as it's parameter
   *   await neetoPlaywrightUtilities.verifyFieldValue([
   *     { field: COMMON_SELECTORS.submitButton, value: "Submit" },
   *     {
   *       field: COMMON_SELECTORS.cancelButton,
   *       value: "cancel",
   *     },
   *   ]);
   * 
   *   // verifyFieldValue with a field-value object as it's parameter
   *   await neetoPlaywrightUtilities.verifyFieldValue({
   *     field: COMMON_SELECTORS.submitButton,
   *     value: "Submit",
   *   });
   * @endexample
  */
  verifyFieldValue: VerifyFieldValue;
  /**
   *
   * Command to search for a term and verify the results and its count.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.searchAndVerify({
   *     searchTerm: "searchTerm",
   *     searchInputSelector: COMMON_SELECTORS.inputField,
   *     countSelector: COMMON_SELECTORS.count,
   *     countText: "43 items",
   *   });
   * @endexample
  */
  searchAndVerify: ({
    searchTerm,
    searchInputSelector,
    countSelector,
    countText
  }: SearchAndVerifyProps) => Promise<void>;
  /**
   *
   * Command to upload an image to image uploader and verify it. It takes the following parameters:
   *
   * localImagePath: Path to image.
   *
   * @example 
   *
   *   await neetoPlaywrightUtilities.uploadImage("../assets/image.png");
   * @endexample
  */
  uploadImage: (localImagePath: string) => Promise<void>;
  verifyTooltip: ({
    triggerElement,
    content
  }: {
    triggerElement: Locator;
    content: string;
  }) => Promise<void>;
}
interface EmailContentParams {
  email: string;
  subjectSubstring?: string;
  timeout?: number;
  receivedAfter?: Date;
}
type FetchOtpFromEmail = (props: EmailContentParams) => Promise<string | undefined>;
declare class MailosaurUtils {
  mailosaur: MailosaurClient;
  serverId: string;
  constructor(mailosaur: MailosaurClient);
  /**
   *
   * Used to extract the email content. It takes the following parameters:
   *
   * email (required): The Mailosaur email to which the OTP was sent to.
   *
   * subjectSubstring (optional): A substring of the email subject to filter it.
   *
   * timeout (optional): The timeout time in milliseconds after which the method
   *
   * throws an error if an email is not found. Defaults to 2 minutes
   *
   * receivedAfter: A date object used to filter the emails based on the time of
   *
   * receiving it. Only emails incoming after this timestamp will be taken into
   *
   * account. Defaults to the timestamp of invoking this method.
   *
   * @example 
   *
   * test("sample test", async ({ mailosaurUtils }) => {
   *   const email = mailosaurUtils.getEmailContent({
   *     email: `someone@${process.env.MAILOSAUR_SERVER_ID}.mailosaur.net`,
   *     subjectSubstring: "is your OTP",
   *     timeout: 60 * 1000,
   *     receivedAfter: new Date(),
   *   });
   * });
   * @endexample
  */
  getEmailContent: ({
    email,
    subjectSubstring,
    timeout,
    receivedAfter
  }: EmailContentParams) => Promise<mailosaur_lib_models.Message>;
  /**
   *
   * Used to extract the OTP from the neeto OTP emails. It takes the following parameters:
   *
   * email(required): The Mailosaur email to which the OTP was sent to.
   *
   * subjectSubstring (optional): A substring of the email subject to filter it.
   *
   * Defaults to "is your login code"
   *
   * timeout (optional): The timeout time in milliseconds after which the method
   *
   * throws an error if an email is not found. Defaults to 2 minutes
   *
   * receivedAfter: A date object used to filter the emails based on the time of
   *
   * receiving it. Only emails incoming after this timestamp will be taken into
   *
   * account. Defaults to the timestamp of invoking this method.
   *
   * @example 
   *
   * test("sample test", async ({ mailosaurUtils }) => {
   *   mailosaurUtils.fetchOtpFromEmail({
   *     email: `someone@${process.env.MAILOSAUR_SERVER_ID}.mailosaur.net`,
   *     subjectSubstring: "is your OTP",
   *     timeout: 60 * 1000,
   *     receivedAfter: new Date(),
   *   });
   * });
   * @endexample
  */
  fetchOtpFromEmail: FetchOtpFromEmail;
  /**
   *
   * Used to generate a random Email ID to the Mailosaur Server.
   *
   * @example 
   *
   * test("sample test", async ({ mailosaurUtils }) => {
   *   const email = mailosaurUtils.generateRandomMailosaurEmail();
   * });
   * @endexample
  */
  generateRandomMailosaurEmail: () => string;
}
interface CustomFixture {
  neetoPlaywrightUtilities: CustomCommands;
  page: Page;
  mailosaur: MailosaurClient;
  mailosaurUtils: MailosaurUtils;
}
type Commands = Fixtures<CustomFixture, PlaywrightWorkerArgs & PlaywrightWorkerOptions, PlaywrightTestArgs & PlaywrightTestOptions, PlaywrightWorkerArgs & PlaywrightWorkerOptions>;
declare const commands: Commands;
/**
 *
 * Function generates staging data for a specified product. It takes the following parameters:
 *
 * product (optional): A string representing the product for which staging data is being generated. Defaults to "invoice" if not provided.
 *
 * @example 
 *
 *   import { generateStagingData } from "@bigbinary/neeto-playwright-commons";
 * 
 *   // Generate staging data for the default product ("invoice")
 *   const stagingData = generateStagingData();
 * 
 *   console.log(stagingData);
 *   
 *   Output:
 *   {
 *     firstName: 'André',
 *     lastName: "O'Reilly",
 *     otp: 111111,
 *     domain: 'neetoinvoice.net',
 *     currentUserName: 'André O'Reilly', // Depends on IS_STAGING_ENV and CREDENTIALS
 *     businessName: 'cpt-invoice-0322153521234', // Timestamp will be different
 *     subdomainName: 'cpt-invoice-0322153521234', // Timestamp will be different if IS_STAGING_ENV is true, else 'spinkart'
 *     email: 'cpt12345+invoice+0322153521234@bigbinary.com' // OTP bypass key will be included if IS_STAGING_ENV is true, else CREDENTIALS.email
 *   }
 * 
 * @endexample
*/
declare const generateStagingData: (product?: string) => {
  firstName: string;
  lastName: string;
  otp: number;
  domain: string;
  currentUserName: string;
  businessName: string;
  subdomainName: string;
  email: string;
};
declare const _default: _playwright_test.TestType<_playwright_test.PlaywrightTestArgs & _playwright_test.PlaywrightTestOptions & Browser, _playwright_test.PlaywrightWorkerArgs & _playwright_test.PlaywrightWorkerOptions>;
declare const i18nFixture: Fixtures<I18nPlaywrightFixture, PlaywrightWorkerArgs & PlaywrightWorkerOptions, PlaywrightTestArgs & PlaywrightTestOptions, PlaywrightWorkerArgs & PlaywrightWorkerOptions>;
type EmbedType = "inline" | "floatingPopup" | "elementClick";
type GetByRoleOptions = {
  checked?: boolean;
  disabled?: boolean;
  exact?: boolean;
  expanded?: boolean;
  includeHidden?: boolean;
  level?: number;
  name?: string | RegExp;
  pressed?: boolean;
  selected?: boolean;
};
type InlineCustomizationOptions = {
  embedHeight: string;
  embedWidth: string;
  embedDivContainerId: string;
};
type VerifyInlineCustomizationParams = {
  headingTestId: string;
  inlineEmbedInterceptParams: Partial<InterceptMultipleResponsesParams>;
  customizationOptions: InlineCustomizationOptions;
};
type FloatingPopupCustomizationOptions = {
  buttonText: string;
  buttonColorHex: string;
  buttonTextColorHex: string;
  buttonPosition: "Bottom left" | "Bottom right";
  showIcon?: boolean;
};
type ElementClickCustomizationOptions = {
  customId: string;
};
type initializeEmbedPageParams = {
  embedType: EmbedType;
  embedCode: string;
  customElementText?: string;
};
type EmbedBasePageConstructorParams = {
  context: BrowserContext;
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  appName: string;
};
declare class EmbedBase {
  context: BrowserContext;
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  appName: string;
  t: TFunction;
  embedTestPage: Page;
  embedTestPageType: EmbedType;
  embeddedFrame: FrameLocator;
  filePath: string;
  codeBlock: Locator;
  previewTab: Locator;
  constructor({
    context,
    page,
    neetoPlaywrightUtilities,
    appName
  }: EmbedBasePageConstructorParams);
  /**
   *
   * Initializes the embed test page. It takes the following parameters:
   *
   * embedType: Type of embedded content (inline, floatingPopup, elementClick).
   *
   * embedCode: Embed code.
   *
   * customElementText: Custom text for element click type (default: "Click here").
   *
   * @example 
   *
   *   await embedBase.initializeEmbedPage({
   *     embedType: "inline",
   *     embedCode: "<iframe src='example.com'></iframe>"
   *   });
   *   // OR
   * 
   *    await embedBase.initializeEmbedPage({
   *     embedType: "inline",
   *     embedCode: "<iframe src='example.com'></iframe>",
   *     customElementText:"Click here"
   *   });
   * @endexample
  */
  initializeEmbedPage: ({
    embedType,
    embedCode,
    customElementText
  }: initializeEmbedPageParams) => Promise<Page>;
  /**
   *
   * Closes the embed modal and page.
   *
   * @example 
   *
   *   await embedBase.closeEmbedModalAndPage();
   * @endexample
  */
  closeEmbedModalAndPage: () => Promise<void>;
  /**
   *
   * Clicks on the popup button.
   *
   * It takes the following parameters as an object:
   *
   * checked: Indicates whether an element is checked.
   *
   * disabled: Indicates whether an element is disabled.
   *
   * exact: Indicates whether an exact match is required.
   *
   * expanded: Indicates whether an element is expanded.
   *
   * includeHidden: Indicates whether hidden elements should be included.
   *
   * level: Specifies the level of the element.
   *
   * name: Specifies the name of the element, which can be a string or a regular expression.
   *
   * pressed: Indicates whether an element is pressed.
   *
   * selected: Indicates whether an element is selected.
   *
   * @example 
   *
   *   await embedBase.clickOnPopupButton({ name: "Popup Button" });
   *   //OR
   *   await embedBase.clickOnPopupButton({
   *     checked: true,
   *     disabled: false,
   *     exact: true,
   *     expanded: false,
   *     includeHidden: false,
   *     level: 2,
   *     name: "Popup Button",
   *     pressed: false,
   *     selected: true
   *   });
   * @endexample
  */
  clickOnPopupButton: (popUpButtonSelectorOptions: GetByRoleOptions) => Promise<void>;
  /**
   *
   * Copies the embed script. It takes the following parameters:
   *
   * embedLabel: Label for the embed script.
   *
   * @example 
   *
   *   const embedScript = await embedBase.copyEmbedScript({ embedLabel: "Embed Script" });
   * @endexample
  */
  copyEmbedScript: ({
    embedLabel
  }: {
    embedLabel: string;
  }) => Promise<string>;
  /**
   *
   * Selects the embed type. It takes the following parameters:
   *
   * embedLabel: Label for the embed type.
   *
   * @example 
   *
   *   await embedBase.selectEmbedType("Inline Embed");
   * @endexample
  */
  selectEmbedType: (embedLabel: string) => Promise<void>;
  /**
   *
   * Verifies inline customization of embedded content. It takes the following parameters:
   *
   * headingTestId: Test ID of the heading element.
   *
   * inlineEmbedInterceptParams: Parameters for intercepting multiple responses.
   *
   * customizationOptions: Options for customization.
   *
   * @example 
   *
   *   await embedBase.verifyInlineCustomization({
   *     headingTestId: "heading",
   *     inlineEmbedInterceptParams: { urlRegex: /example\.com/, status: 200 },
   *     customizationOptions: { embedHeight: "100", embedWidth: "100", embedDivContainerId: "container" }
   *   });
   * @endexample
  */
  verifyInlineCustomization: ({
    headingTestId,
    inlineEmbedInterceptParams,
    customizationOptions
  }: VerifyInlineCustomizationParams) => Promise<void>;
  /**
   *
   * Verifies floating popup customization of embedded content. It takes the following parameters:
   *
   * customizationOptions: Options for customization.
   *
   * @example 
   *
   *   await embedBase.verifyFloatingPopupCustomization({
   *     buttonText: "Popup Button",
   *     buttonColorHex: "#FFFFFF",
   *     buttonTextColorHex: "#000000",
   *     buttonPosition: "Bottom left"
   *   });
   * @endexample
  */
  verifyFloatingPopupCustomization: (customizationOptions: FloatingPopupCustomizationOptions) => Promise<void>;
  /**
   *
   * Verifies element click customization of embedded content. It takes the following parameters:
   *
   * customizationOptions: Options for customization.
   *
   * @example 
   *
   *   await embedBase.verifyElementClickCustomization({ customId: "custom-element" });
   * @endexample
  */
  verifyElementClickCustomization: (customizationOptions: ElementClickCustomizationOptions) => Promise<void>;
  /**
   *
   * Expects multiple texts to be present in the code block. It takes the following parameters:
   *
   * containTextOptions: Array of strings or regex patterns to be checked in the code block.
   *
   * @example 
   *
   *   await embedBase.expectMultipleTextsInCodeblock([
   *     "Text1", "Text2", /Pattern/
   *   ]);
   * @endexample
  */
  expectMultipleTextsInCodeblock: (containTextOptions: [string | RegExp, string | RegExp, ...(string | RegExp)[]]) => Promise<void>;
}
interface HelpAndProfilePageInitializerProps {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  chatApiBaseURL: string;
  kbDocsBaseURL: string;
  changelogBaseURL: string;
}
declare class HelpAndProfilePage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  chatApiBaseURL: string;
  kbDocsBaseURL: string;
  changelogBaseURL: string;
  neetoChatWidget: Locator;
  neetoChatFrame: FrameLocator;
  neetoChatSpinner: Locator;
  t: TFunction;
  profileSectionButton: Locator;
  constructor({
    page,
    neetoPlaywrightUtilities,
    chatApiBaseURL,
    kbDocsBaseURL,
    changelogBaseURL
  }: HelpAndProfilePageInitializerProps);
  private hoverOnBody;
  openHelpCenterV2: () => Promise<void>;
  private openLiveChatAndVerify;
  /**
   *
   * The function reloads the page, opens the chat interface, closes and reopens the chat frame, initiates a new conversation, and verifies the conversation window content.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyChatWidgetV2();
   * @endexample
  */
  openAndVerifyChatWidgetV2: () => Promise<void>;
  /**
   *
   * Opens and verifies the help articles in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyHelpArticlesV2();
   * @endexample
  */
  openAndVerifyHelpArticlesV2: () => Promise<void>;
  private openChangelogPaneV2;
  /**
   *
   * Opens and verifies the changelog in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyChangelogV2();
   * @endexample
  */
  openAndVerifyChangelogV2: () => Promise<void>;
  private formatKeyboardShortcut;
  /**
   *
   * Opens and verifies the keyboard shortcuts pane in Help Center. It takes the following parameters:
   *
   * productShortcuts: Array of objects containing description and sequence of product shortcuts.
   *
   * osPlatform: Platform for keyboard shortcuts ("mac" or "windows").
   *
   * @example 
   *
   *   await helpAndProfilePage.openAndVerifyKeyboardShortcutsPaneV2(productShortcuts, "windows");
   * @endexample
  */
  openAndVerifyKeyboardShortcutsPaneV2: (productShortcuts: {
    description: string;
    sequence: string;
  }[], osPlatform?: "mac" | "windows") => Promise<void>;
  /**
   *
   * Opens and verifies the app switcher in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.openAppSwitcherAndVerifyV2();
   * @endexample
  */
  openAppSwitcherAndVerifyV2: () => Promise<void>;
  private openAuthLinkAndVerify;
  /**
   *
   * Verifies the profile and organization links in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.verifyProfileAndOrganizationLinksV2();
   * @endexample
  */
  verifyProfileAndOrganizationLinksV2: () => Promise<void>;
  /**
   *
   * Verifies logout functionality in Help Center.
   *
   * @example 
   *
   *   await helpAndProfilePage.verifyLogout();
   * @endexample
  */
  verifyLogoutV2: () => Promise<void>;
}
type IntegrationStatus = "connected" | "disconnected";
type PartialInterceptMultipleResponsesParams$1 = Partial<InterceptMultipleResponsesParams>;
interface IntegrationBaseParams {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  integration: string;
  connectedHeader?: string;
  connectHeader?: string;
  pageloaderTimeout?: number;
  integrationRouteIndex?: string;
  integrationRouteResponsesParams?: PartialInterceptMultipleResponsesParams$1;
}
declare class IntegrationBase {
  readonly page: Page;
  readonly neetoPlaywrightUtilities: CustomCommands;
  readonly t: TFunction;
  readonly integration: string;
  readonly integrationCard: Locator;
  readonly connectHeader: string;
  readonly connectedHeader: string;
  pageloaderTimeout: number;
  integrationRouteIndex: string;
  integrationRouteResponsesParams: PartialInterceptMultipleResponsesParams$1;
  constructor({
    page,
    neetoPlaywrightUtilities,
    integration,
    connectHeader,
    connectedHeader,
    pageloaderTimeout,
    integrationRouteIndex,
    integrationRouteResponsesParams
  }: IntegrationBaseParams);
  /**
   *
   * Disconnects an active integration. It takes the following parameters:
   *
   * interceptMultipleResponsesParams: Optional parameter for intercepting multiple responses.
   *
   * @example 
   *
   *   await integrationBase.disconnect();
   *   // OR
   *   await integrationBase.disconnect({
   *     responseUrl: "/auth";
   *     times:1;
   *     baseUrl: "https://www.zoom.com";
   *     responseStatus: 200;
   *   });
   * @endexample
  */
  disconnect: (interceptMultipleResponsesParams?: PartialInterceptMultipleResponsesParams$1) => Promise<void>;
  /**
   *
   * Connects an integration. It takes the following parameters:
   *
   * skipGoTo: Boolean indicating whether to skip navigating to integration index (default: false).
   *
   * @example 
   *
   *   await integrationBase.connect();
   *   // OR
   *   await integrationBase.connect(true);
   * @endexample
  */
  connect: (skipGoTo?: boolean) => Promise<void>;
  /**
   *
   * Verifies the integration status. It takes the following parameters:
   *
   * status: Integration status ("connected" or "disconnected") (default: "connected").
   *
   * visibilityTimeout: Timeout in milliseconds to wait for integration status tag to become visible.
   *
   * @example 
   *
   *   await integrationBase.verifyIntegrationStatus();
   *   // OR
   *   await integrationBase.verifyIntegrationStatus("disconnected");
   * @endexample
  */
  verifyIntegrationStatus: (status?: IntegrationStatus, visibilityTimeout?: number) => Promise<void>;
  /**
   *
   * Clicks on the integration card.
   *
   * @example 
   *
   *   await integrationBase.clickOnIntegrationCard();
   * @endexample
  */
  clickOnIntegrationCard: () => Promise<void>;
  /**
   *
   * Navigates to the integration index route.
   *
   * @example 
   *
   *   await integrationBase.gotoIntegrationIndex();
   * @endexample
  */
  gotoIntegrationIndex: () => Promise<void>;
}
type AsyncNoArgsFunction = () => Promise<void>;
type RedirectUrl = string | RegExp | ((url: URL) => boolean);
type PartialInterceptMultipleResponsesParams = Partial<InterceptMultipleResponsesParams>;
type UpdateConfigureSlackChannelParams = {
  newSlackChannel: string;
  interceptMultipleResponsesParams?: PartialInterceptMultipleResponsesParams;
  refreshInterceptMultipleResponsesParams?: PartialInterceptMultipleResponsesParams;
  refreshChannelList?: boolean;
};
type SlackPageParams = {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  integrationRouteIndex?: string;
};
declare class SlackPage extends IntegrationBase {
  slackWebappPage: Page;
  slackWebappPageDataQa: (dataQa: string | [string, string]) => Locator;
  constructor({
    page,
    neetoPlaywrightUtilities,
    integrationRouteIndex
  }: SlackPageParams);
  /**
   *
   * Closes the coach mark modal, upgrades banner, and permissions banner that appears when a user logs in to Slack for the first time, if present. It can be useful in scenarios where the banners are blocking the view of the elements that needs to be interacted with. It takes the following parameters:
   *
   * slackWebappPage (optional): Playwright Page object for Slack web app.
   *
   * @example 
   *
   * await slackPage.setupCloseHandlers(slackWebappPageInstance);
   * @endexample
  */
  setupCloseHandlers: (slackWebappPage?: Page) => Promise<void>;
  /**
   *
   * Connects to slack integration and verifies the connection. It takes the following parameters:
   *
   * redirectUrl: URL to redirect after connecting.
   *
   * customSteps (optional): Custom steps to perform after connection.
   *
   * channelToConfigure (optional): Channel to configure.
   *
   * @example 
   *
   * await slackPage.connectAndVerifyIntegration(
   *   /example\.com/,
   *   customSteps,
   *   "general"
   * );
   * @endexample
  */
  connectAndVerifyIntegration: (redirectUrl: RedirectUrl, customSteps?: AsyncNoArgsFunction, channelToConfigure?: string) => Promise<void>;
  /**
   *
   * Disconnects from Slack integration and verifies disconnection.
   *
   * @example 
   *
   * await slackPage.disconnectAndVerifyIntegration();
   * @endexample
  */
  disconnectAndVerifyIntegration: () => Promise<void>;
  /**
   *
   * Updates and configures slack channel. It takes the following parameters:
   *
   * newSlackChannel: The name of the slack channel to which the update will be applied.
   *
   * interceptMultipleResponsesParams (optional): Parameters for intercepting multiple responses.
   *
   * refreshInterceptMultipleResponsesParams (optional): Parameters for refreshing intercepting multiple responses.
   *
   * refreshChannelList (optional): Whether to refresh the channel list.
   *
   * @example 
   *
   *   await slackPage.updateConfigureSlackChannel({
   *     newSlackChannel: "example-channel",
   *     refreshChannelList: true
   *   });
   *   //or
   *   await slackPage.updateConfigureSlackChannel({
   *     newSlackChannel: "example-channel",
   *     refreshChannelList: true,
   *     refreshInterceptMultipleResponsesParams:{
   *       responseUrl: "/auth";
   *       times:1;
   *       baseUrl: "https://www.zoom.com";
   *       responseStatus: 200;
   *     },
   *     interceptMultipleResponsesParams:{
   *       responseUrl: "/auth";
   *       times:1;
   *       baseUrl: "https://www.zoom.com";
   *       responseStatus: 200;
   *     }
   *   });
   * @endexample
  */
  updateConfigureSlackChannel: ({
    newSlackChannel,
    interceptMultipleResponsesParams,
    refreshInterceptMultipleResponsesParams,
    refreshChannelList
  }: UpdateConfigureSlackChannelParams) => Promise<void>;
  /**
   *
   * Clicks on the refresh button to update the channel list. It takes the following parameters:
   *
   * refreshInterceptMultipleResponsesParams (optional): Parameters for refreshing intercepting multiple responses.
   *
   * @example 
   *
   *   await slackPage.clickOnChannelListRefreshButton();
   *   // or
   *   await slackPage.clickOnChannelListRefreshButton({
   *         responseUrl: "/auth";
   *         times:1;
   *         baseUrl: "https://www.zoom.com";
   *         responseStatus: 200;
   *     });
   * 
   * @endexample
  */
  clickOnChannelListRefreshButton: (refreshInterceptMultipleResponsesParams?: PartialInterceptMultipleResponsesParams) => Promise<void>;
  /**
   *
   * Note: Either ENV variables SLACK_WORKSPACE, SLACK_LOGIN_PASSWORD and
   *
   * SLACK_LOGIN_EMAIL is required for this method to work or custom credentials
   *
   * workspace, loginPassword and loginEmail must be passed.
   *
   * Logs into slack web app. It takes the following parameters:
   *
   * slackWebappPage: Playwright Page object for Slack web app.
   *
   * customCredentials (optional): Custom credentials for logging in.
   *
   * @example 
   *
   * await slackPage.loginToSlackWebapp(slackWebappPageInstance);
   * // OR
   * await slackPage.loginToSlackWebapp(slackWebappPageInstance, {
   *   loginEmail: "johndoe@gmail.com",
   *   loginPassword: "123456789",
   *   workspace: "your-workspace-name",
   * });
   * @endexample
  */
  loginToSlackWebapp: (slackWebappPage: Page, customCredentials?: Record<"workspace" | "loginPassword" | "loginEmail", string | undefined>) => Promise<void>;
  /**
   *
   * Logs out from slack web app.
   *
   * @example 
   *
   * await slackPage.logoutFromSlackWebApp();
   * @endexample
  */
  logoutFromSlackWebApp: () => Promise<void>;
  /**
   *
   * Navigates to a Slack channel. It takes the following parameters:
   *
   * slackChannel: Name of the Slack channel.
   *
   * @example 
   *
   * await slackPage.goToSlackChannel("general");
   * @endexample
  */
  goToSlackChannel: (slackChannel: string) => Promise<void>;
  /**
   *
   * Creates a new slack channel. It takes the following parameters:
   *
   * channelName: Name of the new Slack channel.
   *
   * kind: Type of the new Slack channel (public or private, optional).
   *
   * @example 
   *
   * await slackPage.createNewSlackChannel({
   *   channelName: "new-channel",
   *   kind: "public",
   * });
   * @endexample
  */
  createNewSlackChannel: ({
    channelName,
    kind
  }: {
    channelName: string;
    kind?: "public" | "private";
  }) => Promise<void>;
  /**
   *
   * Deletes a slack channel. It takes the following parameters:
   *
   * channel: Name of the Slack channel to delete.
   *
   * @example 
   *
   * await slackPage.deleteSlackChannel("old-channel");
   * @endexample
  */
  deleteSlackChannel: (channel: string) => Promise<void>;
}
interface WebhooksPageParams {
  page: Page;
  request: APIRequestContext;
  neetoPlaywrightUtilities: CustomCommands;
  context: BrowserContext;
}
type CallbackFunction = (args: Record<string, unknown>) => void;
interface VerifyWebhookResponseParams extends Record<string, unknown> {
  callback?: CallbackFunction;
  webhookToken: string;
}
interface VerifyWebhookDeliveriesParams extends Record<string, unknown> {
  callback: CallbackFunction;
}
interface VerifyWebhookDeliveryByEventParams extends Record<string, unknown> {
  event: string;
  callbackToVerifyDeliveries: (args: Record<string, unknown>) => void;
}
declare class WebhooksPage {
  page: Page;
  request: APIRequestContext;
  context: BrowserContext;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor({
    page,
    request,
    neetoPlaywrightUtilities,
    context
  }: WebhooksPageParams);
  /**
   *
   * Retrieves the webhook URL and token from a third-party site.
   *
   * Returns: Object containing webhook site URL and token.
   *
   * @example 
   *
   *   const { webhookSiteURL, webhookToken } = await webhooksPage.getWebhookURL();
   * @endexample
  */
  getWebhookURL: () => Promise<{
    webhookSiteURL: string;
    webhookToken: string | undefined;
  }>;
  /**
   *
   * Adds a webhook using the provided webhook site URL. It takes the following parameters:
   *
   * webhookSiteURL: URL of the webhook site.
   *
   * @example 
   *
   *   await webhooksPage.addWebhook({ webhookSiteURL: "https://example.com/webhook" });
   * @endexample
  */
  addWebhook: ({
    webhookSiteURL
  }: {
    webhookSiteURL: string;
  }) => Promise<void>;
  /**
   *
   * Verifies the latest webhook response. It takes the following parameters:
   *
   * callback: Callback function to execute on parsed response.
   *
   * webhookToken: Token of the webhook.
   *
   * Other parameters to be passed to the callback function.
   *
   * @example 
   *
   *   await webhooksPage.verifyLatestWebhookResponse({
   *     callback: ({ parsedResponse }) => console.log(parsedResponse),
   *     webhookToken: "exampleToken"
   *   });
   * @endexample
  */
  verifyLatestWebhookResponse: ({
    callback,
    webhookToken,
    ...otherParams
  }: VerifyWebhookResponseParams) => Promise<void>;
  /**
   *
   * Verifies webhook deliveries. It takes the following parameters:
   *
   * callback: Callback function to execute on parsed response.
   *
   * Other parameters to be passed to the callback function.
   *
   * @example 
   *
   *   await webhooksPage.verifyWebhookDeliveries({
   *     callback: ({ parsedResponse }) => console.log(parsedResponse)
   *   });
   * @endexample
  */
  verifyWebhookDeliveries: ({
    callback,
    ...otherParams
  }: VerifyWebhookDeliveriesParams) => Promise<void>;
  /**
   *
   * Verifies webhook delivery by event. It takes the following parameters:
   *
   * event: Event name.
   *
   * callbackToVerifyDeliveries: Callback function to execute on parsed response.
   *
   * Other parameters to be passed to the callback function.
   *
   * @example 
   *
   *   await webhooksPage.verifyWebhookDeliveryByEvent({
   *     event: "eventName",
   *     callbackToVerifyDeliveries: ({ parsedResponse }) => console.log(parsedResponse)
   *   });
   * @endexample
  */
  verifyWebhookDeliveryByEvent: ({
    event,
    callbackToVerifyDeliveries,
    ...fieldsToBeVerified
  }: VerifyWebhookDeliveryByEventParams) => Promise<void>;
}
declare class ZapierPage extends IntegrationBase {
  zapierWebPage: Page;
  mailosaur: MailosaurClient;
  continueButton: Locator;
  constructor({
    page,
    neetoPlaywrightUtilities,
    integrationRouteIndex
  }: {
    page: Page;
    neetoPlaywrightUtilities: CustomCommands;
    integrationRouteIndex?: string;
  });
  /**
   *
   * Logs into zapier web app. It takes the following parameters:
   *
   * zapierWebPage: Playwright Page object for Zapier web app.
   *
   * @example 
   *
   * await zapierPage.loginToZapier(zapierWebPageInstance);
   * @endexample
  */
  loginToZapier: (zapierWebPage: Page) => Promise<void>;
  /**
   *
   * Logs out from zapier web app.
   *
   * @example 
   *
   * await zapierPage.logoutFromZapier();
   * @endexample
  */
  logoutFromZapier: () => Promise<void>;
  /**
   *
   * Reconnects zapier account and publishes changes. It takes the following parameters:
   *
   * zapierApiKey: Zapier API key.
   *
   * @example 
   *
   * await zapierPage.reconnectAccountAndPublish("your-zapier-api-key");
   * @endexample
  */
  reconnectAccountAndPublish: (zapierApiKey: string) => Promise<void>;
  /**
   *
   * Deletes all connections in zapier. It takes the following parameters:
   *
   * zapierAppLink: Link to Zapier app.
   *
   * @example 
   *
   * await zapierPage.deleteAllConnections("https://zapier.com/app/dashboard");
   * @endexample
  */
  deleteAllConnections: (zapierAppLink: string) => Promise<void>;
  /**
   *
   * Verifies that a Zap is triggered. It takes the following parameters:
   *
   * submittedEmail: Submitted email address.
   *
   * zapTriggeredAfter: Date after which the Zap should be triggered.
   *
   * productName: Name of the product.
   *
   * @example 
   *
   * await zapierPage.verifyZapIsTriggered({
   *   submittedEmail: "example@example.com",
   *   zapTriggeredAfter: new Date(),
   *   productName: "neetoChat",
   * });
   * @endexample
  */
  verifyZapIsTriggered: ({
    productName,
    submittedEmail,
    zapTriggeredAfter
  }: {
    submittedEmail: string;
    zapTriggeredAfter: Date;
    productName: string;
  }) => Promise<mailosaur_lib_models.Message>;
  /**
   *
   * Skips test if Zapier task limit is exhausted.
   *
   * @example 
   *
   * await zapierPage.skipIfTaskLimitIsExhausted();
   * @endexample
  */
  skipIfTaskLimitIsExhausted: () => Promise<void>;
  /**
   *
   * Connects to zapier integration and verifies the connection. It takes the following parameters:
   *
   * apiKeyLabel: Label for Zapier API key.
   *
   * Returns: Zapier API key.
   *
   * @example 
   *
   * const apiKey = await zapierPage.connectAndVerify({ apiKeyLabel: "Your API Key" });
   * @endexample
  */
  connectAndVerify: ({
    apiKeyLabel
  }: {
    apiKeyLabel: string;
  }) => Promise<string>;
  /**
   *
   * Disconnects from Zapier integration and verifies disconnection.
   *
   * @example 
   *
   * await zapierPage.disconnectAndVerify();
   * @endexample
  */
  disconnectAndVerify: () => Promise<void>;
}
interface VerifyDescriptionEditorParams {
  text: string;
  linkUrl?: string;
  filePath?: string;
  attachedImageName?: string;
  imageUrl?: string;
  videoUrl?: string;
  cannedResponseSuccessMessage?: string;
}
declare class EditorPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  paragraphSelector: Locator;
  fixedMenuArrowSelector: Locator;
  editorLinkButton: Locator;
  attachmentPreview: Locator;
  editorAttachmentsButton: Locator;
  imageUploadDeleteButton: Locator;
  imageWrapper: Locator;
  imageUploadOption: Locator;
  cannedResponseOption: Locator;
  videoEmbedOption: Locator;
  videoWrapperSelector: Locator;
  emojiDropdownIcon: Locator;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to verify description editor functionality
   *
   * text (required): The text to be filled in editor content field.
   *
   * linkUrl (optional): The url to be added when we select the button on the editor menu to link a url to a text. Default is faker.internet.url().
   *
   * filePath (optional): The file path to be added when we select the button on the editor menu to attach a file in the editor. Default is "../../../e2e/assets/images/BigBinary.png".
   *
   * imageUrl (optional): The url to be added when we select the button on the editor menu to upload an image in the editor. Default is https://picsum.photos/200/300.
   *
   * videoUrl (optional): The url to be added when we select the button on the editor menu to upload a video in the editor. Default is https://youtu.be/jNQXAC9IVRw.
   *
   * cannedResponseSuccessMessage (optional): The success toastr message after applying canned reesponse.
   *
   * @example 
   *
   * await editorPage.verifyDescriptionEditor({
   *     text: t("tickets.updated_one"),
   *     cannedResponseSuccessMessage: t("messages.successCannedResponse"),
   * });
   * @endexample
  */
  verifyDescriptionEditor: ({
    text,
    linkUrl,
    filePath,
    imageUrl,
    videoUrl,
    cannedResponseSuccessMessage
  }: VerifyDescriptionEditorParams) => Promise<void>;
}
interface CropImageProps {
  toggleAspectRatioLock: boolean;
  aspectRatioHeight: string;
  aspectRatioWidth: string;
  width: string;
  height: string;
}
interface ImageLibraryProps extends Partial<CropImageProps> {
  toggleOrginalImage?: boolean;
  localImagePath: string;
}
interface SelectImage extends CropImageProps {
  toggleOrginalImage: boolean;
  searchTerm: string;
  nthImage: number;
}
declare class ImageUploader {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  constructor({
    page,
    neetoPlaywrightUtilities
  }: {
    page: Page;
    neetoPlaywrightUtilities: CustomCommands;
  });
  private submitCroppedImage;
  /**
   *
   * Used to remove an image already uploaded from the image uploader amd verify it.
   *
   * @example 
   *
   * await imageUploader.removeImage()
   * @endexample
  */
  removeImage: () => Promise<void>;
  /**
   *
   * Used to open the image library modal.
   *
   * @example 
   *
   * await imageUploader.openImageLibrary()
   * @endexample
  */
  openImageLibrary: () => Promise<void>;
  /**
   *
   * Used to crop the image. It takes the following parameters:
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   *     await imageUploader.cropImage({
   *         toggleAspectRatioLock: false
   *         aspectRatioHeight: "9",
   *         aspectRatioWidth: "16",
   *         width: "100",
   *         height: "100",
   *     })
   * @endexample
  */
  cropImage: ({
    toggleAspectRatioLock,
    width,
    height,
    aspectRatioHeight,
    aspectRatioWidth
  }?: Partial<CropImageProps>) => Promise<void>;
  /**
   *
   * Used to upload a new image from the library and crop it if required. It takes the following parameters:
   *
   * localImagePath: The path of the image to be uploaded.
   *
   * toggleOrginalImage (optional): A boolean value to toggle the original image switch which is not checked by default. Default is false.
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   *     await imageUploader.uploadNewImageFromLibrary({
   *         localImagePath,
   *         toggleOrginalImage: false,
   *         toggleAspectRatioLock: false,
   *         aspectRatioHeight: "9",
   *         aspectRatioWidth: "16",
   *         width: "100",
   *         height: "100",
   *     })
   * @endexample
  */
  uploadNewImageFromLibrary: ({
    localImagePath,
    toggleOrginalImage,
    toggleAspectRatioLock,
    aspectRatioHeight,
    aspectRatioWidth,
    width,
    height
  }: ImageLibraryProps) => Promise<void>;
  /**
   *
   * Used to select an image from the unsplash and crop it if required. It takes the following parameters:
   *
   * nthImage (optional): The index of the image to be selected. Default is 0.
   *
   * searchTerm (optional): The input for the search field.
   *
   * toggleOrginalImage (optional): A boolean value to toggle the original image switch which is not checked by default. Default is false.
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   * await imageUploader.selectImageFromWeb({
   *     nthImage: 0,
   *     searchTerm: "",
   *     toggleOrginalImage: false,
   *     toggleAspectRatioLock: false,
   *     aspectRatioHeight: "9",
   *     aspectRatioWidth: "16",
   *     width: "100",
   *     height: "100",
   * })
   * @endexample
  */
  selectImageFromWeb: ({
    nthImage,
    searchTerm,
    toggleOrginalImage,
    toggleAspectRatioLock,
    aspectRatioHeight,
    aspectRatioWidth,
    width,
    height
  }?: Partial<SelectImage>) => Promise<void>;
  /**
   *
   * Used to select an image from the library and crop it if required. It takes the following parameters:
   *
   * nthImage (optional): The index of the image to be selected. Default is 0.
   *
   * searchTerm (optional): The input for the search field.
   *
   * toggleOrginalImage (optional): A boolean value to toggle the original image switch which is not checked by default. Default is false.
   *
   * toggleAspectRatioLock (optional): A boolean value to toggle the aspect ratio lock switch which is checked by default. Default is false.
   *
   * aspectRatioHeight (optional): The height of the aspect ratio. Default is 9.
   *
   * aspectRatioWidth (optional): The width of the aspect ratio. Default is 16.
   *
   * width (optional): The width of the cropped image. Default is 100.
   *
   * height (optional): The height of the cropped image. Default is 100.
   *
   * @example 
   *
   *     await imageUploader.selectImageFromLibrary({
   *         nthImage: 0,
   *         searchTerm: "",
   *         toggleOrginalImage: false,
   *         toggleAspectRatioLock: false,
   *         aspectRatioHeight: "9",
   *         aspectRatioWidth: "16",
   *         width: "100",
   *         height: "100",
   *     })
   * @endexample
  */
  selectImageFromLibrary: ({
    nthImage,
    searchTerm,
    toggleOrginalImage,
    toggleAspectRatioLock,
    aspectRatioHeight,
    aspectRatioWidth,
    width,
    height
  }?: Partial<SelectImage>) => Promise<void>;
}
type sublink = "active" | "deactivated" | "all";
type emailCondition = "Contains" | "Does not contain" | "Is" | "Is not" | "Starts with" | "Does not start with" | "Ends with" | "Does not end with";
interface EditMemberProps$1 {
  email: string;
  firstName: string;
  lastName: string;
  role: string;
}
declare class TeamMembers {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor({
    page,
    neetoPlaywrightUtilities
  }: {
    page: Page;
    neetoPlaywrightUtilities: CustomCommands;
  });
  /**
   *
   * Used to navigate to the specified sublink in the team members page.
   *
   * sublink (optional): The sublink to navigate to. Default is all.
   *
   * @example 
   *
   * await teamMembers.navigateToTeamMembersSublink("all");
   * @endexample
  */
  navigateToTeamMembersSublink: ({
    clickMembersTab,
    sublink
  }?: {
    clickMembersTab?: boolean;
    sublink?: sublink;
  }) => Promise<void>;
  /**
   *
   * Used to add a member using the add button in the header. It takes the following parameters:
   *
   * emails (optional): The emails of the members to be added. Default is an example email.
   *
   * role (optional): The role of the new members. Default is standard.
   *
   * @example 
   *
   * await teamMembers.addMemberViaUI({
   *     emails: ["sam@example.com", "tom@example.com"],
   *     role: "admin",
   * });
   * @endexample
  */
  addMemberViaUI: ({
    emails,
    role
  }?: {
    emails?: string[];
    role?: string;
  }) => Promise<void>;
  /**
   *
   * Used to search and verify the member by providing email as the search term. It takes the following parameters:
   *
   * email (required): The email of the member to be searched.
   *
   * interceptOptions (optional): The options to be passed to the waitForMultipleResponse command.
   *
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   *     interceptOptions: { timeout: 10000, requestCount: 1 },
   * });
   * @endexample
  */
  searchAndVerifyMemberByEmail: ({
    email,
    interceptOptions
  }: {
    email: string;
    interceptOptions?: Partial<Omit<InterceptMultipleResponsesParams, "responseUrl">>;
  }) => Promise<void>;
  /**
   *
   * Used to edit a member using the edit button in row dropdown. A member has to be searched before editing. It takes the following parameters:
   *
   * email (optional): The new email of the member.
   *
   * role (optional): The new role of the member. Default is standard.
   *
   * firstName (optional): The new first name of the member.
   *
   * lastName (optional): The new last name of the member.
   *
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   * });
   * await teamMembers.editMemberViaUI({
   *     email: "tom@example.com",
   *     role: "admin",
   *     firstName: "Tom",
   *     lastName: "Hanks",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   * });
   * await teamMembers.editMemberViaUI();
   * 
   * // This will change the role of the member with email "sam@example.com" to the `standard` role.
   * @endexample
  */
  editMemberViaUI: ({
    email,
    firstName,
    lastName,
    role
  }?: Partial<EditMemberProps$1>) => Promise<void>;
  /**
   *
   * Used to toggle the state of a member between active or deactivated, using the activate or deactivate button in row dropdown. A member has to be searched before toggling.
   *
   * @example 
   *
   * await teamMembers.searchAndVerifyMemberByEmail({
   *     email: "sam@example.com",
   * });
   * await teamMembers.toggleMemberStateViaUI();
   * @endexample
  */
  toggleMemberStateViaUI: () => Promise<void>;
  /**
   *
   * Used to filter members by multi select fields such as role, group, teams, etc. The filter pane should be opened and closed before and after filtering. It takes the following parameters:
   *
   * selectedOptions (required): The options to be selected in the multi select field.
   *
   * selectContainerLocator (optional): The locator of the container of the multi select field. Default is the container of the role field.
   *
   * @example 
   *
   * await filterUtils.openFilterPane(page);
   * await teamMembers.filterMembersByMultiSelect({
   *     selectedOptions: ["Admin", "Standard"],
   *     selectContainerLocator: NEETO_FILTERS_SELECTORS.roleSelectContainer
   * });
   * @endexample
  */
  filterMembersByMultiSelect: ({
    selectedOptions,
    selectContainerLocator
  }: {
    selectedOptions: string[];
    selectContainerLocator?: string;
  }) => Promise<void>;
  /**
   *
   * Used to filter members by at least one these field: email with conditions, role, or name. It takes the following parameters:
   *
   * email (optional): An object with the id and condition as keys to filter by email.
   *
   * roles (optional): The roles to filter by.
   *
   * name (optional): The name to filter by.
   *
   * @example 
   *
   * await teamMembers.filterMembers({
   *     email: { id: "sam", condition: "Contains" },
   *     roles: ["Admin", "Standard"],
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.filterMembers({
   *     name: "Sam",
   *     roles: ["Admin"],
   * });
   * @endexample
  */
  filterMembers: ({
    email,
    roles,
    name
  }: {
    email?: {
      id: string;
      condition: emailCondition;
    };
    roles?: string[];
    name?: string;
  }) => Promise<void>;
  /**
   *
   * Used to get the row of the team members table by providing the name of the member.
   *
   * @example 
   *
   * await teamMembers.getMemberRowByName("Sam");
   * @endexample
  */
  getMemberRowByName: (name: string) => playwright_core.Locator;
  /**
   *
   * Used to take action on members by selecting the members and clicking on the take action button in the subheader. It takes the following parameters:
   *
   * names (optional): The names of the members to take action on. If not provided, all members will be selected.
   *
   * state (optional): The state to change the members to.
   *
   * action (optional): An object with actionButtonText and valueButtonText as keys to take action on the members. actionButtonText and valueButtonText are the text of the action button to be clicked and the value of the action to be changed to, respectively.
   *
   * @example 
   *
   * await teamMembers.takeActionOnMembers({
   *     names: ["Sam", "Tom"],
   *     state: "Deactivate",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.takeActionOnMembers({
   *     action: { actionButtonText: "Change role", valueButtonText: "Admin" },
   * });
   * @endexample
  */
  takeActionOnMembers: ({
    names,
    state,
    action
  }: {
    names?: string[];
    state?: "activate" | "deactivate" | undefined;
    action?: {
      actionButtonText: string;
      valueButtonText: string;
    } | undefined;
  }) => Promise<void>;
  /**
   *
   * Used to perform an action on a column header in the team members table. It takes the following parameters:
   *
   * columnName (optional): The name of the column to perform the action on. Default is Name.
   *
   * actionButtonText (optional): The text of the action button to be clicked. Default is Ascending.
   *
   * @example 
   *
   * await teamMembers.performColumnAction({
   *     columnName: "Role",
   *     actionButtonText: "Hide column",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.performColumnAction();
   * 
   * // This will sort the `name` column in ascending order.
   * @endexample
  */
  performColumnAction: ({
    columnName,
    actionButtonText
  }?: {
    columnName?: string;
    actionButtonText?: "Ascending" | "Descending" | "Hide column";
  }) => Promise<void>;
  /**
   *
   * Used to toggle the visibility of columns in the team members table. It takes the following parameters:
   *
   * columns (optional): The columns whose visibility is to be toggled.
   *
   * bulkAction (optional): The option to show or hide all columns. If not provided, the columns will be toggled individually based on the columns parameter.
   *
   * @example 
   *
   * await teamMembers.toggleMemberColumns({
   *     bulkAction: "show",
   * });
   * @endexample
   * @example 
   *
   * await teamMembers.toggleMemberColumns({
   *     columns: ["role", "email"],
   * });
   * @endexample
  */
  toggleMemberColumns: ({
    columns,
    bulkAction
  }: {
    columns?: string[];
    bulkAction?: "hide" | "show";
  }) => Promise<void>;
  /**
   *
   * Used to verify the presence of a member in the team members table. It takes the following parameters:
   *
   * email (required): The email of the member to be verified.
   *
   * name (optional): The name of the member to be verified.
   *
   * @example 
   *
   * await teamMembers.verifyMemberInTable({
   *     email: "sam@example.com",
   *     name: "Sam",
   * });
   * @endexample
  */
  verifyMemberInTable: ({
    name,
    email
  }: {
    name: string;
    email: string;
  }) => Promise<void>;
}
interface BasicUserInfo {
  firstName: string;
  lastName: string;
  email: string;
}
interface CreateOrganizationProps extends BasicUserInfo {
  businessName: string;
  subdomainName: string;
  appName: string;
}
interface LoginAndOnboardParams extends BasicUserInfo {
  handleOnboarding: () => Promise<void>;
}
interface Credentials extends BasicUserInfo {
  otp?: number;
  domain: string;
  currentUserName: string;
  businessName: string;
  subdomainName: string;
}
declare class OrganizationPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to generate  the subdomain URL. It takes the following parameters:
   *
   * appName(required): Name of the app.
   *
   * @example 
   *
   *   const domain = organizationPage.baseUrlGenerator(appName)
   *   console.log(domain) // https://${subdomainName}.${appName}.net
   *   // "subdomainName" is the loggedIn user name
   * @endexample
  */
  baseUrlGenerator: (appName: string) => string;
  /**
   *
   * Used to create a new organization. It takes the following parameters:
   *
   * email: Owner emails.
   *
   * businessName: Your business name.
   *
   * subdomainName: Your subdomain.
   *
   * firstName: User first name.
   *
   * lastName: User last name.
   *
   * appName: App name
   *
   * @example 
   *
   *   await organizationPage.createOrganization({
   *     email:"jhondoe@gmail.com",
   *     businessName:"BigBinary",
   *     subdomainName:"bigbinary",
   *     firstName:"jhon",
   *     lastName:"doe",
   *     appName:"neetoChat"
   *   })
   * @endexample
  */
  createOrganization: ({
    email,
    businessName,
    subdomainName,
    firstName,
    lastName,
    appName
  }: CreateOrganizationProps) => Promise<void>;
  /**
   *
   * Used to set up an Organization. It takes the following parameters:
   *
   * product: Name of the product.
   *
   * @example 
   *
   *   await organizationPage.setupOrganization("Chat")
   * @endexample
  */
  setupOrganization: (product: string) => Promise<void>;
  /**
   *
   * Used to update already existing subdomain name. It takes the following parameters:
   *
   * appName: Name of the app.
   *
   * @example 
   *
   *   await organizationPage.updateSubdomainIfExists("latest subdomain")
   * @endexample
  */
  updateSubdomainIfExists: (appName: string) => Promise<void>;
  /**
   *
   * Used to login via SSO. It takes the following parameters:
   *
   * email (optional): A bypass email. If not provided, a random bypass email will be generated.
   *
   * loginTimeout (optional): Specifies the maximum amount of time the method will wait for the login process to complete before timing out. Default is 15s.
   *
   * @example 
   *
   *  await organizationPage.loginViaSSO()
   * @endexample
  */
  loginViaSSO: (email?: string, loginTimeout?: number) => Promise<void>;
  /**
   *
   * Used to fill and submit all the profile info. It takes the following parameters:
   *
   * firstName (optional): The first name of the user.
   *
   * lastName (optional): The last name of the user.
   *
   * @example 
   *
   *   await organizationPage.setupProfile({
   *     firstName:"John",
   *     lastName:"Doe"
   *   })
   * @endexample
  */
  setupProfile: ({
    firstName,
    lastName
  }?: {
    firstName?: string;
    lastName?: string;
  }) => Promise<void>;
  /**
   *
   * Used to login and onboard the user to app. It takes the following parameters:
   *
   * email: User email.
   *
   * firstName: User first name.
   *
   * lastName: User last name.
   *
   * handleOnBoard: Method to call after onboarding.
   *
   * @example 
   *
   *   await organizationPage.loginAndOnboard({
   *     email:"jhondoe@gmail.com",
   *     firstName:"jhon",
   *     lastName:"doe",
   *     handleOnboarding:() => methodToOnBoard
   *   })
   * @endexample
  */
  loginAndOnboard: ({
    email,
    firstName,
    lastName,
    handleOnboarding
  }: LoginAndOnboardParams) => Promise<void>;
  /**
   *
   * Used to signUp the user. It takes the following parameters:
   *
   * otp: (optional) OTP to verify the email.
   *
   * fetchOtpFromEmail: (optional) Method to fetch OTP from email.
   *
   * @example 
   *
   *   const fetchOtpFromEmail = (email,timeOut)=>Promise<void>
   * 
   *   const credentials = {
   *     otp:1234,
   *     domain:"chat.com",
   *     currentUserName:"jhon",
   *     businessName:"bigbinary",
   *     subdomainName: "bigbinary"
   *   }
   * 
   *   await organizationPage.signUp({
   *     credentials,
   *     fetchOtpFromEmail,
   *     appName:"neetoChat"
   *   })
   * @endexample
  */
  signUp: ({
    credentials,
    fetchOtpFromEmail,
    appName
  }: {
    credentials: Credentials;
    fetchOtpFromEmail?: (params: {
      email: string;
      timeout: number;
    }) => Promise<string>;
    appName: string;
  }) => Promise<{
    STORAGE_STATE: {
      cookies: {
        name: string;
        value: string;
        domain: string;
        path: string;
        expires: number;
        httpOnly: boolean;
        secure: boolean;
        sameSite: "Strict" | "Lax" | "None";
      }[];
      origins: {
        origin: string;
        localStorage: {
          name: string;
          value: string;
        }[];
      }[];
    };
    baseURL: string | undefined;
  }>;
  /**
   *
   * Used to fill and complete all the details of an Organization.
   *
   * @example 
   *
   *   const credentials = {
   *     otp:1234,
   *     domain:"chat.com",
   *     currentUserName:"jhon",
   *     businessName:"bigbinary",
   *     subdomainName: "bigbinary"
   *   }
   * 
   *   await organizationPage.fillOrganizationDetails({
   *     credentials,
   *     appName:"neetoChat"
   *   })
   * @endexample
  */
  fillOrganizationDetails: ({
    credentials,
    appName
  }: {
    credentials: Credentials;
    appName: string;
  }) => Promise<void>;
}
declare class SidebarSection {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to click on the sub link in the sidebar. It takes the following parameters:
   *
   * label (required): The label of the sub link.
   *
   * @example 
   *
   *   await sideBarPage.clickOnSubLink("open menu item")
   * @endexample
  */
  clickOnSubLink: (label: string) => Promise<void>;
  /**
   *
   * Used to go back to the previous page. It takes the following parameters:
   *
   * label (required): The label of the go back button.
   *
   * @example 
   *
   *   await sideBarPage.sidebarGoBackButton("settings")
   * @endexample
  */
  clickOnGoBackButton: (label: string) => Promise<void>;
}
interface SearchAndSelectProps {
  selector: string;
  tagName: string;
  rowSelector: string;
}
interface MergeTagsViaUIProps {
  sourceTagName: string;
  destinationTagName: string;
  tagsBreadcrumbSelector: string;
}
declare class TagsPage {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  t: TFunction;
  constructor(page: Page, neetoPlaywrightUtilities: CustomCommands);
  /**
   *
   * Used to search and verify the tags by providing tag name as the search term. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be searched.
   *
   * @example 
   *
   * await tagsPage.searchAndVerifyTags("tagName");
   * @endexample
  */
  searchAndVerifyTags: (tagName: string) => Promise<void>;
  /**
   *
   * Used to add a tag using the add button in the header. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be added.
   *
   * addTagsLabel (required): The label of the add new tags pane header.
   *
   * tagsResponseUrl (required): the response URL of tags when the save button is clicked while adding new tags.
   *
   * @example 
   *
   * await tagsPage.addTagViaUI({
   *     tagName: "tagName",
   *     addTagsLabel: "Add new tag",
   *     tagsResponseUrl: API_ROUTES.tags.index,
   * });
   * @endexample
  */
  addTagViaUI: ({
    tagName,
    addTagsLabel,
    tagsResponseUrl
  }: {
    tagName: string;
    addTagsLabel: string;
    tagsResponseUrl: string;
  }) => Promise<void>;
  /**
   *
   * Used to filter tags using the filter button in the header. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be filtered.
   *
   * @example 
   *
   * await tagsPage.filterTagsViaUI({
   *     tagName: "tagName",
   * });
   * @endexample
  */
  filterTagsViaUI: (tagName: string) => Promise<void>;
  /**
   *
   * Used to edit a tag using the edit button in row dropdown. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be edited.
   *
   * newTagName (required): The new name of the tag.
   *
   * @example 
   *
   * await tagsPage.editTagViaUI({
   *     tagName: "tagName",
   *     newTagName: "newTagName",
   * });
   * @endexample
  */
  editTagViaUI: ({
    tagName,
    newTagName
  }: {
    tagName: string;
    newTagName: string;
  }) => Promise<void>;
  /**
   *
   * Used to delete a tag using the delete button in row dropdown. It takes the following parameters:
   *
   * tagName (required): The name of the tag to be deleted.
   *
   * @example 
   *
   * await tagsPage.deleteTagViaUI({
   *     tagName: "tagName",
   * });
   * @endexample
  */
  deleteTagViaUI: (tagName: string) => Promise<void>;
  /**
   *
   * Used to add tags via API request. It takes the following parameters:
   *
   * name (required): The name of the tag to be added.
   *
   * description (optional): The description of the tag to be added. Default is "".
   *
   * tagsRequestUrl (required): The URL of the tags API endpoint.
   *
   * @example 
   *
   * await tagsPage.addTagsViaRequest({
   *     name: "tagName",
   *     description: "tagDescription",
   *     tagsRequestUrl: ROUTES.tags.index,
   * });
   * @endexample
  */
  addTagsViaRequest: ({
    name,
    description,
    tagsRequestUrl
  }: {
    name: string;
    description?: string;
    tagsRequestUrl: string;
  }) => Promise<playwright_core.APIResponse | undefined>;
  /**
   *
   * Used to navigate to merge tags page.
   *
   * @example 
   *
   * await tagsPage.navigateToMergeTagsPage();
   * @endexample
  */
  navigateToMergeTagsPage: () => Promise<void>;
  /**
   *
   * Used to search a tag and select that tag in the tags table. It takes the following parameters:
   *
   * selector (required): The selector used to search a tag.
   *
   * tagName (required): The name of the tag to be searched and selected.
   *
   * rowSelector (required): The selector of the row used to select a tag.
   *
   * @example 
   *
   * await tagsPage.searchAndSelect({
   *     selector: MERGE_TAGS_SELECTORS.sourceSearchTextField,
   *     tagName: "tagName",
   *     rowSelector: MERGE_TAGS_SELECTORS.sourceTagRow,
   * });
   * @endexample
  */
  searchAndSelect: ({
    selector,
    tagName,
    rowSelector
  }: SearchAndSelectProps) => Promise<void>;
  /**
   *
   * Used to merge tags and verify the merged tags in tags table. It takes the following parameters:
   *
   * sourceTagName (required): The name of the source tag to be merged.
   *
   * destinationTagName (required): The name of the destination tag to be merged.
   *
   * tagsBreadcrumbSelector (required): The selector of the tags breadcrumb used to redirect to the tags page.
   *
   * @example 
   *
   * tagsPage.mergeAndVerifyTagsViaUI({
   *     sourceTagName: "sourceTagName",
   *     destinationTagName: "destinationTagName",
   *     tagsBreadcrumbSelector: SETTINGS_SELECTORS.ticketTagsBreadcrumb,
   * })
   * @endexample
  */
  mergeAndVerifyTagsViaUI: ({
    sourceTagName,
    destinationTagName,
    tagsBreadcrumbSelector
  }: MergeTagsViaUIProps) => Promise<void>;
}
/**
 *
 * Constants related to different environments.
 *
 * development: Represents the development environment.
 *
 * staging: Represents the staging environment.
 *
 * review: Represents the review environment.
 *
 * @example 
 *
 * if (process.env.NODE_ENV === ENVIRONMENT.development) {
 *   // Perform actions specific to the development environment
 * }
 * 
 * // OR
 * 
 * if (process.env.NODE_ENV === ENVIRONMENT.staging) {
 *   // Perform actions specific to the staging environment
 * }
 * 
 * // OR
 * 
 * if (process.env.NODE_ENV === ENVIRONMENT.review) {
 *   // Perform actions specific to the review environment
 * }
 * @endexample
*/
declare const ENVIRONMENT: {
  development: string;
  staging: string;
  review: string;
};
/**
 *
 * Boolean value indicating whether the current environment is staging.
 *
 * @example 
 *
 * if(IS_STAGING_ENV){
 *   // Perform actions specific to the staging environment
 * }
 * @endexample
*/
declare const IS_STAGING_ENV: boolean;
/**
 *
 * Path to the JSON file for storing authentication data.
 *
*/
declare const STORAGE_STATE = "./e2e/auth/user.json";
/**
 *
 * Pattern for global translations file path.
 *
*/
declare const GLOBAL_TRANSLATIONS_PATTERN = "../node_modules/@bigbinary/**/translations/en.json";
/**
 *
 * Path to project-specific translations file.
 *
*/
declare const PROJECT_TRANSLATIONS_PATH = "../app/javascript/src/translations/en.json";
/**
 *
 * Default credentials for testing purposes.
 *
*/
declare const CREDENTIALS: {
  name: string;
  email: string;
  password: string;
};
/**
 *
 * Pattern for the subject of OTP emails.
 *
*/
declare const OTP_EMAIL_PATTERN = "is your login code";
/**
 *
 * Default Slack channel.
 *
*/
declare const SLACK_DEFAULT_CHANNEL = "general";
/**
 *
 * Function to generate Zapier test email address based on the product. It takes the following parameters:
 *
 * product: Product name.
 *
 * @example 
 *
 * const testEmail = ZAPIER_TEST_EMAIL("neetoChat");
 * 
 * console.log(testEmail) // `neeto-neetoChat-zapier-test@${process.env.INTEGRATION_MAILOSAUR_SERVER_ID}.mailosaur.net`
 * @endexample
*/
declare const ZAPIER_TEST_EMAIL: (product: string) => string;
declare const USER_AGENTS: {
  windows: string;
  mac: string;
};
/**
 *
 * Description: Base URL for API endpoints.
 *
 * Value: "/api/v1"
 *
 * @example 
 *
 *   import { BASE_URL } from "@bigbinary/neeto-playwright-commons";
 * @endexample
*/
declare const BASE_URL = "/api/v1";
declare const NEETO_AUTH_BASE_URL: (subdomain?: string) => string;
/**
 *
 * Object containing various route URLs.
 *
 * @example 
 *
 *   import { ROUTES } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * neetoAuthSignup: URL for Neeto Auth signup page.
 *
 * neetoAuth: Base URL for Neeto Auth.
 *
 * loginLink: URL for login page.
 *
 * profile: URL for user profile page.
 *
 * admin: URL for admin page.
 *
 * myProfile: URL for personal profile page.
 *
 * authSettings: URL for authentication settings page.
 *
 * webhooks: URL for webhooks page.
 *
 * login: URL for login API endpoint.
 *
 * signup: URL for signup API endpoint.
 *
 * subdomainAvailability: URL for checking subdomain availability API endpoint.
 *
 * countries: URL for countries API endpoint.
 *
 * neetoApps: URL for Neeto Apps API endpoint.
 *
 * teamMembers: Object containing URLs related to team members.
 *
 * all: URL for retrieving all team members.
 *
 * bulkUpdate: URL for bulk updating team members.
 *
 * index: URL for team members index.
 *
 * show(id): Method to generate URL for showing a specific team member's details.
 *
*/
declare const ROUTES: {
  neetoAuthSignup: string;
  neetoAuth: string;
  loginLink: string;
  profile: string;
  admin: string;
  myProfile: string;
  authSettings: string;
  webhooks: string;
  login: string;
  signup: string;
  subdomainAvailability: string;
  countries: string;
  neetoApps: string;
  directUploads: string;
  teamMembers: {
    all: string;
    bulkUpdate: string;
    index: string;
    show: (id: string) => string;
  };
  attachment: string;
};
/**
 *
 * Object containing API route URLs.
 *
 * @example 
 *
 * import { API_ROUTES } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * teamMembers: Object containing URLs related to team members (similar structure to ROUTES).
 *
 * integrations: Object containing URLs for integrations.
 *
 * zapier: Object containing URLs specific to Zapier integration.
 *
 * api_keys: URL for Zapier API keys.
 *
*/
declare const API_ROUTES: {
  teamMembers: {
    all: string;
    bulkUpdate: string;
    index: string;
    show: (id: string) => string;
  };
  integrations: {
    zapier: {
      api_keys: string;
    };
  };
};
/**
 *
 * Object containing URLs for third-party services.
 *
 * @example 
 *
 *  import { THIRD_PARTY_ROUTES } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * webhooks: Object containing URLs for webhook services.
 *
 * site: Base URL for webhook.site.
 *
 * slack: Object containing URLs for Slack.
 *
 * loginWithPassword(workspace): Method to generate URL for logging into Slack workspace using password.
 *
 * @example 
 *
 *   THIRD_PARTY_ROUTES.slack.loginWithPassword("example") // Outputs: "https://example.slack.com/sign_in_with_password"
 * @endexample
 * zapier: Object containing URLs for Zapier.
 *
 * login: URL for Zapier login.
 *
 * logOut: URL for Zapier logout.
 *
 * zapEditor(zapId): Method to generate URL for Zapier Zap editor.
 *
 * @example 
 *
 *   THIRD_PARTY_ROUTES.zapier.zapEditor("123") // Outputs: "https://zapier.com/editor/123"
 * @endexample
*/
declare const THIRD_PARTY_ROUTES: {
  webhooks: {
    site: string;
  };
  slack: {
    loginWithPassword: (workspace: string) => string;
  };
  zapier: {
    login: string;
    logOut: string;
    zapEditor: (zapId: string) => string;
  };
};
declare const NEETO_ROUTES: {
  imageUploader: string;
};
declare const networkConditions: Record<"Slow 3G" | "Fast 3G" | "No Throttling", Protocol.Network.emulateNetworkConditionsParameters>;
/**
 *
 * Common selectors for UI elements.
 *
 * @example 
 *
 * import { COMMON_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * copyButton: Selector for the copy button.
 *
 * resetButton: Selector for the reset button.
 *
 * spinner: Selector for spinners.
 *
 * subheaderText: Selector to get the subheader text.
 *
 * alertTitle: Selector for alert titles.
 *
 * alertModalMessage: Selector for alert modal messages.
 *
 * alertModalSubmitButton: to get the submit button of the neetoUI Alert component.
 *
 * checkbox: Selector for checkboxes.
 *
 * checkboxLabel: Selector for checkbox labels.
 *
 * dropdownContainer: Selector for dropdown containers.
 *
 * dropdownIcon: Selector for dropdown icons.
 *
 * heading: Selector for headings.
 *
 * paneBody: Selector for pane bodies.
 *
 * paneHeader: Selector for pane headers.
 *
 * profileSidebar: Selector for profile sidebars.
 *
 * selectOption(label: string): Method that generates a selector for select options based on the label.
 *
 * radioLabel(embedLabel: string): Method that generates a selector for radio labels based on the embedded label.
 *
 * toastMessage: To get the neetoUI Toastr message.
 *
 * toastCloseButton: To get the neetoUI Toastr close icon.
 *
 * windowAlert: Selector for window alerts.
 *
 * body: Selector for the body.
 *
 * toastIcon: To get the neetoUI Toastr icon.
 *
 * paneModalCrossIcon: Selector for pane modal cross icons.
 *
 * inputField: Selector to get neetoUI input field.
 *
 * alertConfirmationText: Selector for alert confirmation text.
 *
 * alertCancelButton: Selector for alert cancel buttons.
 *
 * alertModalCrossIcon: Selector for alert modal cross icons.
 *
 * saveChangesButton: Selector for save changes buttons.
 *
 * cancelButton: Selector for cancel buttons.
 *
 * inputFieldError: Selector for input field errors.
 *
 * selectDropDownError: Selector for select dropdown errors.
 *
 * subTitleHeading: Selector for subtitle headings.
 *
 * noDataTitle: Selector for no data titles.
 *
 * noDataDescription: Selector for no data descriptions.
 *
 * backdrop: Selector for backdrops.
 *
 * menuBarHeading: Selector for menu bar headings.
 *
 * dropdownWrapper: Selector for dropdown wrappers.
 *
 * toggleButton: Selector for toggle buttons.
 *
 * tooltip: Selector for tooltips.
 *
 * articlePageTitle: Selector for article page titles.
 *
 * tabItem: Selector for tab items.
 *
 * labelInputError: Selector for label input errors.
 *
 * urlInputError: Selector for URL input errors.
 *
 * noDataPrimaryButton: Selector for no data primary buttons.
 *
 * modalHeader: Selector for modal headers.
 *
 * nameInputError: Selector for name input errors.
 *
 * selectContainer: to get the select container.
 *
 * selectValueContainer: Selector for select value containers.
 *
 * dropdownMenu: Selector for dropdown menus.
 *
 * sidebarToggle: Selector for sidebar toggles.
 *
 * subheader: Selector for subheaders.
 *
 * settingsLink: Selector for settings links.
 *
 * ticketFieldTextInput(label: string | number): Method that generates a selector for ticket field text inputs based on the label.
 *
 * appSwitcherButton: Selector for app switcher buttons.
 *
 * appSwitcherWrapper: Selector for app switcher wrappers.
 *
 * tableSpinner: Selector to get the spinner when the table is loading.
 *
 * pageLoader: Selector to get the spinner when the page element is loading.
 *
 * homeButton: Selector for home buttons.
 *
 * neetoUiSwitch: Selector for Neeto UI switches.
 *
 * floatingActionMenuButton: Selector for floating action menu buttons.
 *
 * columnsDropdownContainer: Selector for columns dropdown containers.
 *
 * columnsDropdownButton: Selector for columns dropdown buttons.
 *
 * breadcrumbHeader: Selector for breadcrumb headers.
 *
 * header: Selector to get the page header.
 *
 * sidebarSubLink(label: string): Method that generates a selector for sidebar sub-links based on the label.
 *
 * sidebarGoBackButton(label: string): Method that generates a selector for sidebar go-back buttons based on the label.
 *
 * selectSingleValue: Selector for select single values.
 *
*/
declare const COMMON_SELECTORS: {
  emailInputError: string;
  pane: string;
  sideBar: string;
  copyButton: string;
  resetButton: string;
  spinner: string;
  subheaderText: string;
  alertTitle: string;
  alertModalMessage: string;
  alertModalSubmitButton: string;
  checkbox: string;
  checkboxLabel: string;
  dropdownContainer: string;
  dropdownIcon: string;
  heading: string;
  paneBody: string;
  paneHeader: string;
  profileSidebar: string;
  selectOption: (label: string) => string;
  radioLabel: (embedLabel: string) => string;
  toastMessage: string;
  toastCloseButton: string;
  windowAlert: string;
  body: string;
  toastIcon: string;
  paneModalCrossIcon: string;
  inputField: string;
  alertBox: string;
  tableContainer: string;
  alertConfirmationText: string;
  alertCancelButton: string;
  alertModalCrossIcon: string;
  saveChangesButton: string;
  cancelButton: string;
  inputFieldError: string;
  selectDropDownError: string;
  subTitleHeading: string;
  noDataTitle: string;
  noDataDescription: string;
  backdrop: string;
  menuBarHeading: string;
  dropdownWrapper: string;
  toggleButton: string;
  tooltip: string;
  articlePageTitle: string;
  tabItem: string;
  labelInputError: string;
  urlInputError: string;
  noDataPrimaryButton: string;
  modalHeader: string;
  nameInputError: string;
  selectContainer: string;
  selectValueContainer: string;
  dropdownMenu: string;
  sidebarToggle: string;
  subheader: string;
  settingsLink: string;
  ticketFieldTextInput: (label: string | number) => string;
  appSwitcherButton: string;
  appSwitcherWrapper: string;
  tableSpinner: string;
  pageLoader: string;
  homeButton: string;
  neetoUiSwitch: string;
  floatingActionMenuButton: string;
  columnsDropdownContainer: string;
  columnsDropdownButton: string;
  breadcrumbHeader: string;
  header: string;
  sidebarSubLink: (label: string) => string;
  sidebarGoBackButton: (label: string) => string;
  selectSingleValue: string;
  actionSelectIndicator: string;
  takeActionDropdown: string;
  columnsSearchInput: string;
  errorToastIcon: string;
  nuiRadioLabel: string;
  submitButton: string;
  tableRow: string;
};
/**
 *
 * Selectors for Neeto editor components.
 *
 * @example 
 *
 * import { NEETO_EDITOR_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * boldOption: Selector for the bold option.
 *
 * italicOption: Selector for the italic option.
 *
 * underlineOption: Selector for the underline option.
 *
 * strikeOption: Selector for the strike option.
 *
 * codeBlockOption: Selector for the code block option.
 *
 * highlightOption: Selector for the highlight option.
 *
 * linkInput: Selector for the link input.
 *
 * linkSubmitButton: Selector for the link submit button.
 *
 * commandList(index: number): Method that generates a selector for command list items based on the index.
 *
 * imageUploadUrlSubmitButton: Selector for the image upload URL submit button.
 *
 * imageUploadUrlInputTextField: Selector for the image upload URL input text field.
 *
 * uploadInput: Selector for the upload input.
 *
 * editorMenuBarWrapper: Selector for the editor menu bar wrapper.
 *
 * undoOption: Selector for the undo option.
 *
 * redoOption: Selector for the redo option.
 *
 * imageWrapper: Selector for the image wrapper.
 *
 * contentField: Selector for the content field.
 *
 * addLinkButton: Selector for the add link button.
 *
 * addLinkTextField: Selector for the add link text input field.
 *
 * addURLTextField: Selector for the add URL input field.
 *
 * submitLinkButton: Selector for the submit link button.
 *
 * errorText: Selector for the error text.
 *
 * content: Selector for the editor content.
 *
*/
declare const NEETO_EDITOR_SELECTORS: {
  boldOption: string;
  italicOption: string;
  underlineOption: string;
  strikeOption: string;
  codeBlockOption: string;
  highlightOption: string;
  linkInput: string;
  linkSubmitButton: string;
  commandList: (index: number) => string;
  imageUploadUrlSubmitButton: string;
  imageUploadUrlInputTextField: string;
  uploadInput: string;
  editorMenuBarWrapper: string;
  undoOption: string;
  redoOption: string;
  imageWrapper: string;
  contentField: string;
  addLinkButton: string;
  addLinkTextField: string;
  addURLTextField: string;
  submitLinkButton: string;
  fontSizeDropdown: (currentOption?: string) => string;
  fixedMenuArrow: string;
  cannedResponseOption: string;
  cannedResponseSelectContainer: string;
  fixedMenuWrapper: string;
  linkOption: string;
  addLinkUrlInput: string;
  addLinkDoneButton: string;
  unlinkButton: string;
  editorAttachmentsButton: string;
  attachmentPreviewDeleteButton: string;
  imageUploadOption: string;
  imageUploadLinkInput: string;
  imageUploadButton: string;
  imageUploadLinkSubmitButton: string;
  applyButton: string;
  videoEmbedOption: string;
  videoEmbedInput: string;
  videoEmbedSubmit: string;
  videoWrapper: string;
  paragraphOption: string;
  attachmentPreview: string;
  imageUploadLinkButton: string;
  errorText: string;
  content: string;
  imageUploadDeleteButton: string;
};
declare const NEETO_TEXT_MODIFIER_SELECTORS: {
  strikeOption: string;
  underlineOption: string;
  highlightOption: string;
};
declare const TEXT_MODIFIER_SELECTORS: {
  boldOption: string;
  italicsOption: string;
  codeOption: string;
  blockquoteOption: string;
  codeblockOption: string;
};
declare const LIST_MODIFIER_SELECTORS: {
  bulletListOption: string;
  orderedListOption: string;
};
declare const FONT_SIZE_SELECTORS: {
  h1: string;
  h2: string;
  h3: string;
  h4: string;
  h5: string;
};
/**
 *
 * Selectors for Neeto filters components.
 *
 * @example 
 *
 * import { NEETO_FILTERS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * emailSelectContainer: Selector for the email select container wrapper.
 *
 * filterPaneHeading: Selector for the Neeto filters pane header.
 *
 * neetoFiltersEmailBlock: Selector for the Neeto filters email block.
 *
 * neetoFiltersRoleBlock: Selector for the Neeto filters role block.
 *
 * neetoFiltersBarClearButton: Selector for the Neeto filters bar clear button.
 *
 * neetoFiltersNameFilterField: Selector for the Neeto filters name filter field.
 *
 * neetoFilterNameBlock: Selector for the Neeto filter name block.
 *
 * roleSelectContainer: Selector for the role select container wrapper.
 *
 * filterButton: Selector for the Neeto filters toggle button.
 *
 * filtersClearButton: Selector for the Neeto filters clear button.
 *
 * filterDoneButton: Selector for the Neeto filters done button.
 *
 * filteredMembersCount: Selector for the filtered members count.
 *
 * allMenubarBlock: Selector for the all menubar block.
 *
 * filtersEmailFilter: Selector for the Neeto filters email filter.
 *
 * paneModalCrossIcon: Selector for the Neeto filters pane modal cross icon.
 *
 * searchTermBlock: Selector for the Neeto filters search term block.
 *
*/
declare const NEETO_FILTERS_SELECTORS: {
  emailSelectContainer: string;
  filterPaneHeading: string;
  neetoFiltersEmailBlock: string;
  neetoFiltersRoleBlock: string;
  neetoFiltersBarClearButton: string;
  neetoFiltersNameFilterField: string;
  neetoFilterNameBlock: string;
  roleSelectContainer: string;
  filterButton: string;
  filtersClearButton: string;
  filterDoneButton: string;
  filteredMembersCount: string;
  allMenubarBlock: string;
  filtersEmailFilter: string;
  paneModalCrossIcon: string;
  searchTermBlock: string;
  neetoFiltersFilter: (filterName: string) => string;
};
/**
 *
 * Selectors for Help Center components.
 *
 * @example 
 *
 * import { HELP_CENTER_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * helpButton: Selector for the help button.
 *
 * documentationButton: Selector for the documentation button.
 *
 * keyboardShortcutButton: Selector for the keyboard shortcut button.
 *
 * chatButton: Selector for the chat button.
 *
 * whatsNewButton: Selector for the "What's New" button.
 *
 * whatsNewWidgetInfo: Selector for the "What's New" widget info.
 *
 * whatsNewWidgetCloseButton: Selector for the "What's New" widget close button.
 *
 * keyboardShortcutPaneHeading: Selector for the keyboard shortcut pane heading.
 *
 * keyboardShortcutPaneCrossIcon: Selector for the keyboard shortcut pane cross icon.
 *
*/
declare const HELP_CENTER_SELECTORS: {
  helpButton: string;
  documentationButton: string;
  keyboardShortcutButton: string;
  chatButton: string;
  whatsNewButton: string;
  whatsNewWidgetInfo: string;
  whatsNewWidgetCloseButton: string;
  keyboardShortcutPaneHeading: string;
  keyboardShortcutPaneCrossIcon: string;
};
/**
 *
 * Selectors for login components.
 *
 * @example 
 *
 * import { LOGIN_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * appleAuthenticationButton: Selector for the Apple authentication button.
 *
 * emailTextField: Selector to get the email field.
 *
 * googleAuthenticationButton: Selector for the Google authentication button.
 *
 * githubAuthenticationButton: Selector for the GitHub authentication button.
 *
 * loginViaEmailButton: Selector for the login via email button.
 *
 * passwordTextField: Selector for the password text field.
 *
 * rememberMeCheckBox: Selector for the remember me check box.
 *
 * submitButton: Selector for the submit button.
 *
 * twitterAuthenticationButton: Selector for the Twitter authentication button.
 *
*/
declare const LOGIN_SELECTORS: {
  appleAuthenticationButton: string;
  emailTextField: string;
  googleAuthenticationButton: string;
  githubAuthenticationButton: string;
  loginViaEmailButton: string;
  passwordTextField: string;
  rememberMeCheckBox: string;
  submitButton: string;
  twitterAuthenticationButton: string;
};
/**
 *
 * Selectors for member components.
 *
 * @example 
 *
 * import { MEMBER_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * membersTab: Selector for the members tab.
 *
 * newButton: Selector for the "New" button to add a new member.
 *
 * continueButton: Selector for the "Continue" button.
 *
 * submitButton: Selector for the "Submit" button.
 *
 * searchTextField: Selector for the search text field.
 *
 * deactivatedAgentsButton: Selector for the deactivated agents button.
 *
 * activatedMembersButton: Selector for the activated members button.
 *
 * columnCheckBox: Selector to get the neetoUI checkbox.
 *
 * roleLabel(role: string): Method that generates a selector for role labels based on the role.
 *
 * dropDownIcon: Selector to get the neetoUI Dropdown icon button.
 *
 * editButton: Selector for the edit button.
 *
 * menuBarHeading: Selector for the menu bar heading.
 *
 * activateOrDeactivateMember: Selector for the activate or deactivate member button.
 *
 * columnsButton: Selector for the columns button.
 *
 * columnsDropdownContainer: Selector for the columns dropdown container.
 *
 * emailDropdownItemLabel: Selector for the email dropdown item label.
 *
 * roleDropdownItemLabel: Selector for the role dropdown item label.
 *
 * inviteStatusDropdownItemLabel: Selector for the invite status dropdown item label.
 *
 * heading: Selector for the manage members pane header.
 *
 * activateButton: Selector for the activate members button.
 *
 * deactivateButton: Selector for the deactivate members button.
 *
 * rolesButton: Selector for the manage member roles button.
 *
 * statusTag: Selector for the member status tag.
 *
*/
declare const MEMBER_SELECTORS: {
  membersTab: string;
  newButton: string;
  continueButton: string;
  submitButton: string;
  searchTextField: string;
  deactivatedAgentsButton: string;
  activatedMembersButton: string;
  columnCheckBox: string;
  roleLabel: (role: string) => string;
  teamMembersTable: string;
  dropDownIcon: string;
  editButton: string;
  menuBarHeading: string;
  activateOrDeactivateMember: string;
  columnsButton: string;
  columnsDropdownContainer: string;
  emailDropdownItemLabel: string;
  roleDropdownItemLabel: string;
  inviteStatusDropdownItemLabel: string;
  heading: string;
  activateButton: string;
  deactivateButton: string;
  rolesButton: string;
  statusTag: string;
  menubarSubLink: (sublink: string) => string;
  takeActionStateOption: (option?: string) => string;
  checkboxLabel: (label: string) => string;
};
/**
 *
 * Selectors for member form components.
 *
 * @example 
 *
 * import { MEMBER_FORM_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * emailTextField: Selector for the email text field in the member form.
 *
 * firstNameTextField: Selector for the first name text field in the member form.
 *
 * lastNameTextField: Selector for the last name text field in the member form.
 *
 * emailInput: Selector for the email input in the member form.
 *
 * emailErrorField: Selector for the email error field in the member form.
 *
 * cancelButton: Selector for the cancel button in the member form.
 *
*/
declare const MEMBER_FORM_SELECTORS: {
  emailTextField: string;
  firstNameTextField: string;
  lastNameTextField: string;
  emailInput: string;
  emailErrorField: string;
  cancelButton: string;
};
/**
 *
 * Selectors for roles components.
 *
 * @example 
 *
 * import {
 *  ROLES_SELECTORS
 * } from "@bigbinary/neeto-playwright-commons";
 * 
 * @endexample
 * newButton: Selector for the "New" button to add a new role.
 *
 * proceedButton: Selector for the "Proceed" button.
 *
 * cancelButton: Selector for the "Cancel" button.
 *
 * tableHeaderRoleName: Selector for the table header role name.
 *
 * nameTextField: Selector for the name text field when adding or updating a role.
 *
 * searchTextField: Selector for the search text field for roles.
 *
 * updateRolePaneHeading: Selector for the heading when updating a role.
 *
 * updateRoleCancelButton: Selector for the cancel button when updating a role.
 *
 * descriptionTextField: Selector for the description text field when adding or updating a role.
 *
 * permissionCategoryTitle: Selector for the title of the permission category.
 *
 * headerColumn: Selector for the header column of the roles table.
 *
 * dropDownIcon: Selector for the dropdown icon in the roles table header.
 *
 * tableHeaderRoleTitle: Selector for the title in the roles table header.
 *
 * permissionCheckbox: Selector for the permission checkbox.
 *
 * editRoleButton: Selector for the edit role button in the roles table.
 *
 * deleteRoleButton: Selector for the delete role button in the roles table.
 *
 * permissionCard: Selector for the permission card.
 *
*/
declare const ROLES_SELECTORS: {
  newButton: string;
  proceedButton: string;
  cancelButton: string;
  tableHeaderRoleName: string;
  nameTextField: string;
  searchTextField: string;
  updateRolePaneHeading: string;
  updateRoleCancelButton: string;
  descriptionTextField: string;
  permissionCategoryTitle: string;
  headerColumn: string;
  dropDownIcon: string;
  tableHeaderRoleTitle: string;
  permissionCheckbox: string;
  editRoleButton: string;
  deleteRoleButton: string;
  permissionCard: string;
};
/**
 *
 * @example 
 *
 * import { SIGNUP_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * Selectors for signup components.
 *
 * emailTextField: Selector for the email text field in the signup form.
 *
 * firstNameTextField: Selector for the first name text field in the signup form.
 *
 * lastNameTextField: Selector for the last name text field in the signup form.
 *
 * organizationNameTextField: Selector for the organization name text field in the signup form.
 *
 * organizationSubmitButton: Selector for the organization submit button in the signup form.
 *
 * otpTextBox: Selector for the OTP input text box in the signup form.
 *
 * profileSubmitButton: Selector for the profile submit button in the signup form.
 *
 * signupViaEmailButton: Selector for the signup via email button.
 *
 * submitButton: Selector for the submit button in the signup form.
 *
 * subdomainNameTextField: Selector for the subdomain name text field in the signup form.
 *
 * subdomainError: Selector for the subdomain input error message in the signup form.
 *
 * tryFreeButton: Selector for the "Try Free" button.
 *
 * unregisterdEmailError: Selector for the error message when using an unregistered email in the signup form.
 *
*/
declare const SIGNUP_SELECTORS: {
  emailTextField: string;
  firstNameTextField: string;
  lastNameTextField: string;
  organizationNameTextField: string;
  organizationSubmitButton: string;
  otpTextBox: string;
  profileSubmitButton: string;
  signupViaEmailButton: string;
  submitButton: string;
  subdomainNameTextField: string;
  subdomainError: string;
  tryFreeButton: string;
  unregisterdEmailError: string;
};
/**
 *
 * Selectors for tags components.
 *
 * @example 
 *
 * import { TAGS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * newTagButton: Selector for the "New Tag" button.
 *
 * tagNameTextField: Selector for the tag name text field.
 *
 * editButton: Selector for the edit button for tags.
 *
 * deleteButton: Selector for the delete button for tags.
 *
 * cancelButton: Selector for the cancel button when managing tags.
 *
 * submitButton: Selector for the submit button when managing tags.
 *
 * searchTextField: Selector for the search text field for tags.
 *
 * descriptionTextArea: Selector for the description text area for tags.
 *
*/
declare const TAGS_SELECTORS: {
  newTagButton: string;
  tagNameTextField: string;
  editButton: string;
  deleteButton: string;
  cancelButton: string;
  submitButton: string;
  searchTextField: string;
  descriptionTextArea: string;
  addTagButton: string;
  tagSearchField: string;
  deleteTagButton: string;
  metaDataCard: string;
  metaDataBlock: string;
  tagContainer: string;
};
/**
 *
 * Selectors for merging tags components.
 *
 * @example 
 *
 * import { MERGE_TAGS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * mergeTagsButton: Selector for the "Merge Tags" button.
 *
 * mergeButton: Selector for the merge button.
 *
 * sourceSearchTextField: Selector for the search text field in the source tags section.
 *
 * sourceTagsList: Selector for the list of source tags.
 *
 * destinationTagsList: Selector for the list of destination tags.
 *
 * destinationSearchTextField: Selector for the search text field in the destination tags section.
 *
 * cancelButton: Selector for the cancel button when merging tags.
 *
 * proceedButton: Selector for the proceed button when merging tags.
 *
 * disabledTag: Selector for disabled tags.
 *
*/
declare const MERGE_TAGS_SELECTORS: {
  mergeTagsButton: string;
  mergeButton: string;
  sourceSearchTextField: string;
  sourceTagsList: string;
  destinationTagsList: string;
  destinationSearchTextField: string;
  cancelButton: string;
  proceedButton: string;
  disabledTag: string;
  sourceTagRow: string;
  destinationTagRow: string;
};
/**
 *
 * Selectors for the chat widget components.
 *
 * @example 
 *
 * import { CHAT_WIDGET_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * iframe: Selector for the chat widget iframe.
 *
 * spinner: Selector for the spinner in the chat widget.
 *
 * helpButton: Selector for the help button in the chat widget.
 *
 * preChatEmailInput: Selector for the email input in the pre-chat section of the chat widget.
 *
 * preChatSubmitButton: Selector for the submit button in the pre-chat section of the chat widget.
 *
 * chatBubble: Selector for the chat message bubble in the chat widget.
 *
 * closeChat: Selector for the close button in the chat widget.
 *
*/
declare const CHAT_WIDGET_SELECTORS: {
  iframe: string;
  spinner: string;
  helpButton: string;
  preChatEmailInput: string;
  preChatSubmitButton: string;
  chatBubble: string;
  closeChat: string;
};
/**
 *
 * @example 
 *
 * import { CHANGELOG_WIDGET_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * Selectors for the changelog widget components.
 *
 * changelogWrapper: Selector for the wrapper of the changelog widget.
 *
 * closeButton: Selector for the close button in the changelog widget.
 *
 * publicUrlLink: Selector for the public URL link in the changelog widget.
 *
*/
declare const CHANGELOG_WIDGET_SELECTORS: {
  changelogWrapper: string;
  closeButton: string;
  publicUrlLink: string;
};
/**
 *
 * Selectors for the keyboard shortcuts pane components.
 *
 * @example 
 *
 * import { KEYBOARD_SHORTCUTS_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * keyboardShortcutsPane: Selector for the keyboard shortcuts pane.
 *
 * closePaneButton: Selector for the close button in the keyboard shortcuts pane.
 *
 * hotKeyItem: Selector for the hotkey item in the keyboard shortcuts pane.
 *
*/
declare const KEYBOARD_SHORTCUTS_SELECTORS: {
  keyboardShortcutsPane: string;
  closePaneButton: string;
  hotKeyItem: string;
};
/**
 *
 * Selectors for profile section components.
 *
 * @example 
 *
 * import { PROFILE_SECTION_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * profileSectionButton: Selector for the profile section button.
 *
 * profilePopup: Selector for the profile popup.
 *
 * myProfileButton: Selector for the "My Profile" button.
 *
 * profileOrganizationSettingsButton: Selector for the profile organization settings button.
 *
 * logoutButton: Selector for the logout button.
 *
 * neetoAuthLink: Selector for the Neeto authentication link button.
 *
 * profileSidebarCancelButton: Selector for the profile sidebar cancel button.
 *
*/
declare const PROFILE_SECTION_SELECTORS: {
  profileSectionButton: string;
  profilePopup: string;
  myProfileButton: string;
  profileOrganizationSettingsButton: string;
  logoutButton: string;
  neetoAuthLink: string;
  profileSidebarCancelButton: string;
};
/**
 *
 * Selectors for Slack components.
 *
 * @example 
 *
 * import { SLACK_SELECTORS} from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * messageContainer: Selector for the message container.
 *
 * loginEmail: Selector for the login email input.
 *
 * loginPassword: Selector for the login password input.
 *
 * signInButton: Selector for the sign-in button.
 *
 * teamPicketButtonContent: Selector for the team picker button content.
 *
 * redirectOpenInBrowser: Selector for the redirect "open in browser" button.
 *
 * workspaceActionsButton: Selector for the workspace actions button.
 *
 * teamMenuTrigger: Selector for the team menu trigger.
 *
 * menuItemButton: Selector for the menu item button.
 *
 * threadsFlexpane: Selector for the threads flexpane.
 *
 * replyBar: Selector for the reply bar.
 *
 * markdownElement: Selector for the markdown element.
 *
 * virtualListItem: Selector for the virtual list item.
 *
 * channelItems: Selector for channel items.
 *
*/
declare const SLACK_SELECTORS: {
  messageContainer: string;
  loginEmail: string;
  loginPassword: string;
  signInButton: string;
  teamPicketButtonContent: string;
  redirectOpenInBrowser: string;
  workspaceActionsButton: string;
  teamMenuTrigger: string;
  menuItemButton: string;
  threadsFlexpane: string;
  replyBar: string;
  markdownElement: string;
  virtualListItem: string;
  channelItems: string;
};
/**
 *
 * Selectors for Slack components using 'data-qa' attributes.
 *
 * @example 
 *
 * import { SLACK_DATA_QA_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * sectionHeadingButton: Selector for the section heading button.
 *
 * channelSectionSubmenuCreate: Selector for the channel section submenu create button.
 *
 * channelSectionMenuCreateChannel: Selector for the channel section menu create channel button.
 *
 * skModalContent: Selector for the modal content.
 *
 * infiniteSpinner: Selector for the infinite spinner.
 *
 * channelNameOptionsList: Selector for the channel name options list.
 *
 * channelNameInput: Selector for the channel name input.
 *
 * createChannelNextButton: Selector for the create channel next button.
 *
 * inviteToWorkspaceSkipButton: Selector for the invite to workspace skip button.
 *
 * menuItems: Selector for the menu items.
 *
 * channelDetailsModal: Selector for the channel details modal.
 *
 * channelDetailsSettingsTab: Selector for the channel details settings tab.
 *
*/
declare const SLACK_DATA_QA_SELECTORS: {
  sectionHeadingButton: string;
  coachMarkCloseButton: string;
  messagePaneBannerCloseIcon: string;
  permissionBannerCloseIcon: string;
  channelSectionSubmenuCreate: string;
  channelSectionMenuCreateChannel: string;
  skModalContent: string;
  infiniteSpinner: string;
  channelNameOptionsList: string;
  channelNameInput: string;
  createChannelNextButton: string;
  inviteToWorkspaceSkipButton: string;
  menuItems: string;
  channelDetailsModal: string;
  channelDetailsSettingsTab: string;
};
/**
 *
 * Selectors for integration components.
 *
 * @example 
 *
 * import { INTEGRATION_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * integrationCard(integration: string): Method that generates a selector for the integration card based on the integration name. Accepts a string parameter representing the integration name.
 *
 * connectButton: Selector for the connect button.
 *
 * integrationStatusTag: Selector for the integration status tag.
 *
 * disconnectButton: Selector for the disconnect button.
 *
 * manageButton: Selector for the manage button.
 *
*/
declare const INTEGRATION_SELECTORS: {
  integrationCard: (integration: string) => string;
  connectButton: string;
  integrationStatusTag: string;
  disconnectButton: string;
  manageButton: string;
};
/**
 *
 * Selectors for Zapier components.
 *
 * @example 
 *
 * import { ZAPIER_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * zapTriggerStep(zapId: string): Method that generates a selector for the Zap trigger step based on the Zap ID. Accepts a string parameter representing the Zap ID.
 *
 * zapAccountSubstep: Selector for the Zap account substep.
 *
 * zapOpenSubstepContainer: Selector for the container to open substeps.
 *
 * modal: Selector for modals.
 *
 * fmPrettytext: Selector for pretty text.
 *
 * spinner: Selector for spinners.
 *
 * skeletonBlock: Selector for skeleton blocks.
 *
 * accountsLoader: Selector for accounts loader.
 *
 * floatingBox: Selector for floating boxes.
 *
 * connection: Selector for connections.
 *
 * deleteConnectionModal: Selector for the delete connection modal.
 *
 * deleteConnectionDropdownButton: Selector for the dropdown button to delete a connection.
 *
 * usageAmounts: Selector for usage amounts.
 *
 * universalSidebar: Selector for the universal sidebar.
 *
 * sidebarFooter: Selector for the sidebar footer.
 *
 * contextualSideBar: Selector for the contextual sidebar.
 *
*/
declare const ZAPIER_SELECTORS: {
  zapTriggerStep: (zapId: string) => string;
  zapAccountSubstep: string;
  zapOpenSubstepContainer: string;
  modal: string;
  fmPrettytext: string;
  spinner: string;
  skeletonBlock: string;
  accountsLoader: string;
  floatingBox: string;
  connection: string;
  deleteConnectionModal: string;
  deleteConnectionDropdownButton: string;
  usageAmounts: string;
  universalSidebar: string;
  sidebarFooter: string;
  contextualSideBar: string;
};
/**
 *
 * Selectors for embed components.
 *
 * @example 
 *
 * import { EMBED_SELECTORS } from "@bigbinary/neeto-playwright-commons";
 * @endexample
 * iframe(appName: string): Method that generates a selector for the iframe based on the app name.
 *
 * modal(appName: string): Method that generates a selector for the modal based on the app name.
 *
 * close(appName: string): Method that generates a selector for the close button based on the app name.
 *
 * loader(appName: string): Method that generates a selector for the loader based on the app name.
 *
 * inlineHeightInput: Selector for the inline height input field.
 *
 * inlineWidthInput: Selector for the inline width input field.
 *
 * inlineElementIdInput: Selector for the inline element ID input field.
 *
 * codeBlock: Selector for the code block.
 *
 * previewTab: Selector for the preview tab.
 *
 * htmlTab: Selector for the HTML tab.
 *
 * buttonTextInput: Selector for the button text input field.
 *
 * buttonPositionSelectContainer: Selector for the button position select container.
 *
 * buttonPositionSelectMenu: Selector for the button position select menu.
 *
 * buttonColorLabel: Selector for the button color label.
 *
 * buttonTextColorLabel: Selector for the button text color label.
 *
 * colorPickerTarget: Selector for the color picker target.
 *
 * colorpickerEditableInput: Selector for the color picker editable input.
 *
 * showIconCheckbox: Selector for the show icon checkbox.
 *
 * elementIdInput: Selector for the element ID input field.
 *
 * previewElementPopupButton: Selector for the preview element popup button.
 *
*/
declare const EMBED_SELECTORS: {
  iframe: (appName: string) => string;
  modal: (appName: string) => string;
  close: (appName: string) => string;
  loader: (appName: string) => string;
  inlineHeightInput: string;
  inlineWidthInput: string;
  inlineElementIdInput: string;
  codeBlock: string;
  previewTab: string;
  htmlTab: string;
  buttonTextInput: string;
  buttonPositionSelectContainer: string;
  buttonPositionSelectMenu: string;
  buttonColorLabel: string;
  buttonTextColorLabel: string;
  colorPickerTarget: string;
  colorpickerEditableInput: string;
  showIconCheckbox: string;
  elementIdInput: string;
  previewElementPopupButton: string;
};
declare const NEETO_IMAGE_UPLOADER_SELECTORS: {
  imageUploaderWrapper: string;
  browseText: string;
  fileInput: string;
  uploadedImage: string;
  uploadNewAsset: string;
  basicImageUploaderRemoveButton: string;
  removeButton: string;
  openImageLibraryButton: string;
  openAssetLibraryButton: string;
  imageEditorBackButton: string;
  aspectRatioWidthInput: string;
  aspectRatioHeightInput: string;
  cropSubmitButton: string;
  restrictionMessage: string;
  progressBar: string;
  myImagesTab: string;
  unsplashTab: string;
  nthLibraryImage: (index: number) => string;
  nthUnsplashImage: (index: number) => string;
  unsplashSearchInput: string;
  imageEditorUploadedImage: string;
  selectOriginalImageSwitch: string;
  lockAspectRatioSwitch: string;
  widthInputField: string;
  heightInputField: string;
};
/**
 *
 * newConversation: Text for initiating a new conversation.
 *
 * welcomeChatBubble: Text for the welcome message displayed in the chat bubble.
 *
*/
declare const CHAT_WIDGET_TEXTS: {
  newConversation: string;
  welcomeChatBubble: string;
};
/**
 *
 * agent: Text representing an agent.
 *
*/
declare const MEMBER_TEXTS: {
  agent: string;
  admin: string;
  selectAll: string;
  hide: string;
  show: string;
};
/**
 *
 * connectHeader(integration): Method to generate text for connecting an integration account.
 *
 * connectedHeader(integration): Method to generate text indicating a successful connection to an integration.
 *
*/
declare const INTEGRATIONS_TEXTS: {
  connectHeader: (integration: string) => string;
  connectedHeader: (integration: string) => string;
};
/**
 *
 * signOut: Text for signing out.
 *
 * allow: Text for allowing.
 *
 * loadingThread: Text indicating thread loading.
 *
 * name: Text for name.
 *
 * deleteThisChannel: Text for deleting a channel.
 *
 * permanentlyDeleteTheChannel: Text for confirming permanent deletion of a channel.
 *
 * deleteChannel: Text for deleting a channel.
 *
*/
declare const SLACK_WEB_TEXTS: {
  signOut: string;
  allow: string;
  loadingThread: string;
  name: string;
  deleteThisChannel: string;
  permanentlyDeleteTheChannel: string;
  deleteChannel: string;
};
/**
 *
 * account: Text for account.
 *
 * email: Text for email.
 *
 * continue: Text for continue.
 *
 * statusLabel: Text for status label.
 *
 * editExistingDraft: Text for editing an existing draft.
 *
 * signInTo: Text for signing into Zapier.
 *
 * yesContinueTo: Text for confirming continuation to a specific destination.
 *
 * testTrigger: Text for testing a trigger.
 *
 * editStep: Text for editing a step.
 *
 * continueWithSelectedRecord: Text for continuing with a selected record.
 *
 * publish: Text for publishing.
 *
 * delete: Text for deleting.
 *
 * loading: Text indicating loading.
 *
 * subdomain: Text for subdomain.
 *
 * apiKey: Text for API key.
 *
 * publishingZapHeading: Text heading for preparing Zap to go live.
 *
 * connectionListMenu: Text for connection list item menu.
 *
 * usageRegExp: Text for usage reset information.
 *
 * trialEndsRegExp: Text for trial end date.
 *
 * testCurrentlyInQueue: Text indicating test currently in queue.
 *
 * welcomeText(zapierLoginEmail): Method to generate welcome text for Zapier login.
 *
*/
declare const ZAPIER_WEB_TEXTS: {
  account: string;
  email: string;
  continue: string;
  statusLabel: string;
  password: string;
  editExistingDraft: string;
  signInTo: string;
  yesContinueTo: string;
  testTrigger: string;
  editStep: string;
  continueWithSelectedRecord: string;
  publish: string;
  delete: string;
  loading: string;
  subdomain: string;
  apiKey: string;
  publishingZapHeading: string;
  connectionListMenu: string;
  usageRegExp: string;
  trialEndsRegExp: string;
  testCurrentlyInQueue: string;
  welcomeText: (zapierLoginEmail: string) => string;
};
/**
 *
 * zapierApiKeyGenerated: Message indicating successful generation of Zapier API key.
 *
*/
declare const TOASTR_MESSAGES: {
  zapierApiKeyGenerated: string;
};
/**
 *
 * Text indicating that Zapier's free task limit is exhausted and the test will be aborted.
 *
*/
declare const ZAPIER_LIMIT_EXHAUSTED_MESSAGE = "Zapier free task limit is exhausted. Test will be aborted";
declare const EMOJI_PICKER_LABEL = "Smileys & People";
declare const ATTACHMENT_DELETION_TOASTR_MESSAGE = "Attachment has been successfully deleted.";
declare const DESCRIPTION_EDITOR_TEXTS: {
  fontSize: string;
  paragraph: string;
  pasteLink: string;
  invalidURLError: string;
  pasteURL: string;
  delete: string;
  linkTag: string;
  link: string;
  cannedResponseHeader: string;
  paragraphOption: string;
};
declare const EXPANDED_FONT_SIZE: {
  h1: string;
  h2: string;
  h3: string;
  h4: string;
  h5: string;
};
declare const TEXT_MODIFIER_TAGS: {
  underlineOption: string;
  strikeOption: string;
  highlightOption: string;
};
declare const TEXT_MODIFIER_ROLES: {
  boldOption: string;
  italicsOption: string;
  blockquoteOption: string;
  codeblockOption: string;
  codeOption: string;
};
declare const LIST_MODIFIER_TAGS: {
  bulletListOption: string;
  orderedListOption: string;
};
/**
 *
 * Function to initialize credentials of the current user in the storageState.
 *
 * @example 
 *
 *   initializeCredentials("invoice");
 * @endexample
*/
declare const initializeCredentials: (product: string) => void;
interface KeyValue {
  key: string;
  value: string;
}
type JoinString = (string1: string, string2: string, string3?: string, separator?: string) => string;
interface UserContext {
  user: Record<string, string>;
  headers: Record<string, unknown>;
}
type ReadFileSyncIfExists = (path?: string) => UserContext & Record<string, object>;
type WriteDataToFile = (data: string) => boolean;
type UpdateCredentials = ({
  key,
  value
}: KeyValue) => boolean;
type ClearCredentials = () => void;
type Hyphenize = (input: number | string) => string;
type JoinHyphenCase = (args: string) => string;
/**
 *
 * Joins multiple strings with an optional separator. It takes the following parameters:
 *
 * string1: The first string to join.
 *
 * string2: The second string to join.
 *
 * string3 (optional): The third string to join.
 *
 * separator (optional): The separator to use between strings. Default is an empty string.
 *
 * @example 
 *
 *   const result = joinString("Open", "AI", "is", "-");
 *   console.log(result); // Output: Open-AI-is
 * @endexample
*/
declare const joinString: JoinString;
/**
 *
 * Reads the contents of a JSON file synchronously if it exists, otherwise returns an empty object. It takes the following parameters:
 *
 * path (optional): The path of the file to read. Default is STORAGE_STATE.
 *
 * @example 
 *
 *   readFileSyncIfExists()
 * @endexample
*/
declare const readFileSyncIfExists: ReadFileSyncIfExists;
/**
 *
 * Returns the current logged in user info.
 *
 * @example 
 *
 *   const user = getGlobalUserState()
 * @endexample
*/
declare const getGlobalUserState: () => Record<string, string>;
/**
 *
 * Writes data to STORAGE_STATE file.  It takes the following parameters:
 *
 * data: The data to write to the file.
 *
 * @example 
 *
 *   writeDataToFile("neeto")
 * @endexample
*/
declare const writeDataToFile: WriteDataToFile;
/**
 *
 * Updates credentials with a new key-value pair in the STORAGE_STATE json file. It takes the following parameters:
 *
 * key: The key of the credential to update.
 *
 * value: The new value to assign to the credential.
 *
 * @example 
 *
 *   updateCredentials({
 *     key:"name",
 *     value:'oliver'
 *   })
 * @endexample
*/
declare const updateCredentials: UpdateCredentials;
/**
 *
 * Used to remove or delete all the credentials
 *
 * @example 
 *
 *   removeCredentialFile()
 * @endexample
*/
declare const removeCredentialFile: ClearCredentials;
declare const clearCredentials: ClearCredentials;
/**
 *
 * Used to hyphenize the strings. It takes the following parameters:
 *
 * input: The string that need to hyphenized.
 *
 * @example 
 *
 *   import {hyphenize} from  "@bigbinary/neeto-playwright-commons"
 *   const name = hyphenize("hello world")
 *   console.log(name) // hello-world
 * @endexample
*/
declare const hyphenize: Hyphenize;
/**
 *
 * Joins multiple strings into a hyphen-separated lowercase string. It takes the following parameters:
 *
 * ...args (string[]): The strings to join.
 *
 * @example 
 *
 *   const result1 = joinHyphenCase("Hello", "World");
 *   console.log(result1); // Output: hello-world
 * @endexample
*/
declare const joinHyphenCase: JoinHyphenCase;
/**
 *
 * Provides functions to skip tests based on the environment.
 *
 * forDevelopmentEnv: Skips the test if the environment is development.
 *
 * forReviewEnv: Skips the test if the environment is review.
 *
 * forAllExceptStagingEnv: Skips the test if the environment is not staging.
 *
 * forNonNightlyRun: Skips the test if it's not a nightly run in the staging environment.
 *
 * ifNotWithinAllowedNightlyHours: Skips the test if it's not within the allowed nightly run hours.
 *
 * reason: The reason for skipping the test.
 *
 * allowedNightlyRunHours (optional): An array of numbers representing the allowed hours for nightly runs. Default is [0, 6, 12, 18].
 *
 * @example 
 *
 *   // Example usage forDevelopmentEnv:
 *   skipTest.forDevelopmentEnv();
 * 
 *   // Example usage forReviewEnv:
 *   skipTest.forReviewEnv();
 * 
 *   // Example usage forAllExceptStagingEnv:
 *   skipTest.forAllExceptStagingEnv();
 * 
 *   // Example usage forNonNightlyRun:
 *   skipTest.forNonNightlyRun();
 * 
 * 
 *   // Example usage ifNotWithinAllowedNightlyHours:
 *   skipTest.ifNotWithinAllowedNightlyHours({
 *     reason: "outside allowed nightly run hours",
 *     allowedNightlyRunHours: [0, 6, 12, 18]
 *   })
 * @endexample
*/
declare const skipTest: {
  forDevelopmentEnv: () => void;
  forReviewEnv: () => void;
  forAllExceptStagingEnv: () => void;
  forNonNightlyRun: () => void;
  ifNotWithinAllowedNightlyHours: ({
    reason,
    allowedNightlyRunHours
  }: {
    reason: string;
    allowedNightlyRunHours?: number[];
  }) => void;
};
/**
 *
 * Checks whether setup and teardown should be skipped.
 *
 * @example 
 *
 *   const shouldSkip = shouldSkipSetupAndTeardown()
 * @endexample
*/
declare const shouldSkipSetupAndTeardown: () => boolean | "";
/**
 *
 * Trims and replaces multiple whitespace characters in a string with a single space. It takes the following parameters:
 *
 * text: The text that need to be squished.
 *
 * @example 
 *
 *   const textWithExtraSpaces = "   Hello    world   ";
 *   const squishedText = squish(textWithExtraSpaces);
 * 
 *   console.log(squishedText); // Output will be "Hello world"
 * @endexample
*/
declare const squish: (text: string) => string;
/**
 *
 * Converts a string to camel case. It takes the following parameters:
 *
 * text: The text that need to be converted to camel case.
 *
 * @example 
 *
 *   const inputString = "hello_world";
 *   const camelCaseString = toCamelCase(inputString);
 * 
 *   console.log(camelCaseString); // Output will be "helloWorld"
 * @endexample
*/
declare const toCamelCase: (string: string) => string;
/**
 *
 * Creates a function to locate elements by the data-qa attribute on a page.
 *
 * @example 
 *
 *   // Using getByDataQA to find an element with a single data-qa attribute
 *   getByDataQA(page, 'some_data_qa_value');
 * 
 * 
 *   // Using getByDataQA to find a nested element with two data-qa attributes
 *   const findElementByNestedDataQA = getByDataQA(page, ['parent_data_qa_value', 'child_data_qa_value']);
 * 
 *   // Now you can use the located elements as needed
 *   await findElementBySingleDataQA.click();
 *   await findElementByNestedDataQA.hover();
 * @endexample
*/
declare const getByDataQA: ts_toolbelt_out_Function_Curry.Curry<(page: Page, dataQa: string | [string, string]) => playwright_core.Locator>;
declare const getListCount: ({
  page,
  countSelector
}: {
  page: Page;
  countSelector: string;
}) => Promise<number>;
interface LoginProps {
  page: Page;
  neetoPlaywrightUtilities: CustomCommands;
  loginPath?: string;
}
/**
 *
 * Used to login by using email and password. It takes the following parameters:
 *
 * loginPath (optional): The path to which the user should be redirected for login.
 *
 * page: A page object
 *
 * neetoPlaywrightUtilities: An object of type NeetoPlaywrightUtilities
 *
 * @example 
 *
 *   import { loginWithoutSSO } from "@bigbinary/neeto-playwright-commons"
 * 
 *   await loginWithoutSSO({
 *     page,
 *     neetoPlaywrightUtilities,
 *     loginPath:"/home"
 *   })
 * @endexample
*/
declare const loginWithoutSSO: ({
  page,
  neetoPlaywrightUtilities,
  loginPath
}: LoginProps) => Promise<void>;
/**
 *
 * Used to Login to App
 *
 * Only works in staging environment. It takes the following parameters:
 *
 * loginPath (optional): The path to which the user should be redirected for login. Default is /
 *
 * page: A page object
 *
 * neetoPlaywrightUtilities: An object of type NeetoPlaywrightUtilities
 *
 * @example 
 *
 *   import { login } from "@bigbinary/neeto-playwright-commons"
 * 
 *   login({
 *     page,
 *     neetoPlaywrightUtilities,
 *     loginPath:"/home"
 *   })
 * @endexample
*/
declare const login: ({
  page,
  neetoPlaywrightUtilities,
  loginPath
}: LoginProps) => Promise<false | void>;
/**
 *
 * Function to generate a random email to bypass OTP verification and log into
 *
 * neeto products.
 *
 * @example 
 *
 *   import { generateRandomBypassEmail } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const bypassEmail = generateRandomBypassEmail();
 * @endexample
*/
declare const generateRandomBypassEmail: () => string;
/**
 *
 * Used to extract subdomain from the error message.
 *
 * @example 
 *
 *  extractSubdomainFromError("https://wwww.bb.neetoChat.com") // bb
 * @endexample
*/
declare const extractSubdomainFromError: (errorString: string) => string;
interface AddMemberProps {
  email: string;
  role?: string;
  appName: string;
  requestCount?: number;
  neetoPlaywrightUtilities: CustomCommands;
}
interface EditMemberProps {
  email: string;
  firstName?: string;
  lastName?: string;
  newRole?: string;
  requestCount?: number;
  neetoPlaywrightUtilities: CustomCommands;
}
interface DeactiveMemberProps {
  email: string;
  neetoPlaywrightUtilities: CustomCommands;
  requestCount?: number;
}
declare const memberUtils: {
  /**
   *
   * Adds a member to the team via API request. It takes the following parameters:
   *
   * email: Email of the member to be added.
   *
   * role: Role of the member (default: "Agent").
   *
   * appName: Name of the application.
   *
   * neetoPlaywrightUtilities: Custom utility functions for API requests.
   *
   * requestCount (optional): Specify the number of requests.
   *
   * @example 
   *
   *   import { memberUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   await memberUtils.addMemberViaRequest({
   *       email: "example@example.com",
   *       appName: "MyApp",
   *       neetoPlaywrightUtilities: myCustomPlaywrightUtilities,
   *   });
   * 
   *   // OR
   * 
   *   await memberUtils.addMemberViaRequest({
   *       email: "example@example.com",
   *       appName: "MyApp",
   *       neetoPlaywrightUtilities: myCustomPlaywrightUtilities,
   *       requestCount:10
   *   });
   * @endexample
  */
  addMemberViaRequest: ({
    email,
    role,
    appName,
    neetoPlaywrightUtilities
  }: AddMemberProps) => Promise<playwright_core.APIResponse | undefined>;
  /**
   *
   * Edits a member's details via API request. It takes the following parameters:
   *
   * email: Email of the member to be edited.
   *
   * firstName (optional): New first name of the member.
   *
   * lastName (optional): New last name of the member.
   *
   * newRole (optional): New role of the member.
   *
   * neetoPlaywrightUtilities: Custom utility functions for API requests.
   *
   * requestCount (optional): Specify the number of requests.
   *
   * @example 
   *
   *   import { memberUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   await memberUtils.editMemberViaRequest({
   *       email: "example@example.com",
   *       firstName: "John",
   *       lastName: "Doe",
   *       newRole: "Admin",
   *       neetoPlaywrightUtilities: myCustomPlaywrightUtilities,
   *   });
   * 
   *   await memberUtils.editMemberViaRequest({
   *       email: "example@example.com",
   *       firstName: "John",
   *       lastName: "Doe",
   *       newRole: "Admin",
   *       neetoPlaywrightUtilities: myCustomPlaywrightUtilities,
   *       requestCount:10
   *   })
   * @endexample
  */
  editMemberViaRequest: ({
    email,
    firstName,
    lastName,
    newRole,
    neetoPlaywrightUtilities
  }: EditMemberProps) => Promise<void>;
  /**
   *
   * Deactivates a member via API request. It takes the following parameters:
   *
   * email: Email of the member to be deactivated.
   *
   * neetoPlaywrightUtilities: Custom utility functions for API requests.
   *
   * requestCount (optional): Specify the number of requests.
   *
   * @example 
   *
   *   import { memberUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   await memberUtils.deactivateMemberViaRequest({
   *       email: "example@example.com",
   *       neetoPlaywrightUtilities: myCustomPlaywrightUtilities,
   *   });
   * 
   *   // OR
   * 
   *   await memberUtils.deactivateMemberViaRequest({
   *       email: "example@example.com",
   *       neetoPlaywrightUtilities: myCustomPlaywrightUtilities,
   *       requestCount:2
   *   });
   * @endexample
  */
  deactivateMemberViaRequest: ({
    email,
    neetoPlaywrightUtilities
  }: DeactiveMemberProps) => Promise<playwright_core.APIResponse | undefined>;
  generateRandomTeamMembers: ({
    count,
    role
  }: {
    count?: number | undefined;
    role?: string | undefined;
  }) => {
    firstName: string;
    lastName: string;
    email: string;
    role: string;
  }[];
};
interface AssertColumnHeaderVisibilityProps {
  page: Page;
  columnName: string;
  shouldBeVisible: boolean;
}
interface ToggleColumnCheckboxAndVerifyVisibilityProps {
  page: Page;
  tableColumns: string[];
  shouldBeChecked: boolean;
}
declare const tableUtils: {
  /**
   *
   * Used to check if columns exist in table or not. It takes the following parameters:
   *
   * page: A page object.
   *
   * columnNames: Array of column names to be checked.
   *
   * @example 
   *
   *  import { tableUtils } from  "@bigbinary/neeto-playwright-commons"
   * 
   *  await tableUtils.verifyTableColumnsExistence({
   *   page,
   *   columnNames,
   *  });
   * @endexample
  */
  verifyTableColumnsExistence: ({
    page,
    columnNames
  }: {
    page: Page;
    columnNames: string[];
  }) => Promise<void>;
  /**
   *
   * Used to check if the provided column matches the given visibility option. It takes the following parameters:
   *
   * page:  A page object.
   *
   * columnName: Name of the column.
   *
   * shouldBeVisible: Status of the column checkbox.
   *
   * @example 
   *
   *  import { tableUtils } from "@bigbinary/neeto-playwright-commons"
   * 
   *  await tableUtils.assertColumnHeaderVisibility({
   *       page,
   *       columnName,
   *       shouldBeVisible :true,
   *   });
   * @endexample
  */
  assertColumnHeaderVisibility: ({
    page,
    columnName,
    shouldBeVisible
  }: AssertColumnHeaderVisibilityProps) => Promise<void>;
  /**
   *
   * Used to toggle columns from the subheader's show/hide columns button. The columns are then verified in the table. It takes the following parameters:
   *
   * page: A page object.
   *
   * tableColumns: Array of column names to be toggled.
   *
   * shouldBeChecked : Status of the column checkbox.
   *
   * @example 
   *
   *   import { tableUtils } from "@bigbinary/neeto-playwright-commons"
   * 
   *   await tableUtils.toggleColumnCheckboxAndVerifyVisibility({
   *     page,
   *     tableColumns,
   *     shouldBeChecked: false,
   *   });
   * @endexample
  */
  toggleColumnCheckboxAndVerifyVisibility: ({
    page,
    tableColumns,
    shouldBeChecked
  }: ToggleColumnCheckboxAndVerifyVisibilityProps) => Promise<void>;
};
interface BreadcrumbTitleAndRoute {
  title: string;
  route: string;
}
interface VerifyBreadcrumbProps {
  page: Page;
  titlesAndRoutes: BreadcrumbTitleAndRoute[];
}
declare const headerUtils: {
  /**
   *
   * Verifies the breadcrumbs in the header of a web page. It takes the following parameters:
   *
   * page: An instance of the Playwright Page class representing the web page where the breadcrumbs are located.
   *
   * titlesAndRoutes: An array of objects containing the titles and routes of the breadcrumbs to verify.
   *
   * @example 
   *
   *   import { Page } from "@playwright/test";
   *   import { headerUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   const breadcrumbs = [
   *     { title: "Home", route: "/" },
   *     { title: "Category", route: "/category" },
   *     { title: "Subcategory", route: "/category/subcategory" }
   *   ];
   * 
   *   await headerUtils.verifyBreadcrumbs({
   *    page,
   *    titlesAndRoutes: breadcrumbs
   *   });
   * @endexample
  */
  verifyBreadcrumbs: ({
    page,
    titlesAndRoutes
  }: VerifyBreadcrumbProps) => Promise<void>;
};
/**
 *
 * Decodes a QR code from an image file and returns the decoded string.
 *
 * filePath: A string representing the path to the image file containing the QR code.
 *
 * Returns: A string representing the decoded content of the QR code, or undefined if decoding fails.
 *
 * @example 
 *
 *   import { decodeQRCodeFromFile } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const filePath = "path/to/qrCodeImage.png";
 * 
 *   const decodedString = await decodeQRCodeFromFile(filePath);
 * @endexample
*/
declare const decodeQRCodeFromFile: (filePath: string) => Promise<string | undefined>;
/**
 *
 * Initializes TOTP authentication by creating a TOTP instance with the specified issuer and secret. It takes the following parameters:
 *
 * issuer: A string representing the issuer name for TOTP authentication.
 *
 * secret: A string or a Secret object representing the secret key for TOTP generation.
 *
 * Returns: A TOTP object initialized with the provided issuer, algorithm, digits, period, and secret.
 *
 * @example 
 *
 *   import { initializeTotp } from "@bigbinary/neeto-playwright-commons";
 * 
 *   // Initialize TOTP with issuer and secret
 *   const issuer = "MyApp";
 *   const secret = "my_secret_key";
 *   const totp = initializeTotp({ issuer, secret });
 * 
 *   // Generate TOTP token
 *   const token = totp.generate();
 *   console.log("TOTP Token:", token);
 * @endexample
*/
declare const initializeTotp: ({
  issuer,
  secret
}: {
  issuer: string;
  secret: string | Secret;
}) => TOTP;
type EmulateNetworkConditionsParameters = Protocol.Network.emulateNetworkConditionsParameters;
type NetworkThrottlingUsingCdpParams = {
  cdpSession: CDPSession;
  emulateNetworkConditionsParameters?: EmulateNetworkConditionsParameters;
};
/**
 *
 * Throttles network conditions using CDP. It takes the following parameters:
 *
 * cdpSession: A CDPSession instance for sending CDP commands.
 *
 * emulateNetworkConditionsParameters (optional): An object representing the network conditions to emulate. Default is "Fast 3G" conditions.
 *
 * Throttles CPU usage using CDP. It takes the following parameters:
 *
 * cdpSession: A CDPSession instance for sending CDP commands.
 *
 * rate (optional): A number representing the throttling rate as a slowdown factor. Default is 1.25.
 *
 * @example 
 *
 *   import { cpuThrottlingUsingCDP } from "@bigbinary/neeto-playwright-commons";
 * 
 *   cpuThrottlingUsingCDP({
 *     cdpSession
 *   })
 * @endexample
 * Executes code with throttled network and/or CPU resources. It takes the following parameters:
 *
 * code: A function representing the code to execute.
 *
 * kind (optional): A string specifying the type of throttling to apply. Can be "both" (default), "network", or "cpu".
 *
 * networkCondition (optional): An object representing the network conditions to emulate.
 *
 * cpuThrottlingRate (optional): A number representing the CPU throttling rate as a slowdown factor.
 *
 * cdpSession: A CDPSession instance for sending CDP commands.
 *
 * @example 
 *
 *   import { networkConditions } from "@constants/networkConditions";
 *   import { executeWithThrottledResources } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const emulateNetworkConditionsParameters = networkConditions["Fast 3G"];
 *   const cpuThrottlingRate = 2;
 * 
 *   await executeWithThrottledResources({
 *     code: async () => {
 *       // Your code to emulate network and CPU throttling
 *     },
 *     kind: "both",
 *     networkCondition: emulateNetworkConditionsParameters,
 *     cpuThrottlingRate,
 *     cdpSession, // Provide the CDPSession instance
 *   });
 * @endexample
*/
declare const networkThrottlingUsingCDP: ({
  cdpSession,
  emulateNetworkConditionsParameters
}: NetworkThrottlingUsingCdpParams) => Promise<Protocol.Network.emulateNetworkConditionsReturnValue>;
type CpuThrottlingUsingCdpParams = {
  cdpSession: CDPSession;
  rate?: number;
};
declare const cpuThrottlingUsingCDP: ({
  cdpSession,
  rate
}: CpuThrottlingUsingCdpParams) => Promise<Protocol.Emulation.setCPUThrottlingRateReturnValue>;
interface ExecuteWithThrottledResourcesParams {
  kind?: "both" | "network" | "cpu";
  code: () => Promise<void>;
  networkCondition?: EmulateNetworkConditionsParameters;
  cpuThrottlingRate?: number;
  cdpSession: CDPSession;
}
declare const executeWithThrottledResources: ({
  code: emulatedCode,
  kind,
  networkCondition,
  cpuThrottlingRate,
  cdpSession
}: ExecuteWithThrottledResourcesParams) => Promise<void>;
/**
 *
 * Function to generate a basic HTML content with the given body.
 *
 * @example 
 *
 *    basicHTMLContent(`
 *        <h1>Hello world</h1>
 *    `)
 * 
 * @endexample
*/
declare const basicHTMLContent: (content: string) => string;
/**
 *
 * This function converts a hexadecimal color code to its RGB equivalent.
 *
 * hex: A string representing the hexadecimal color code to be converted to RGB.
 *
 * @example 
 *
 *    import { hexToRGB } from "@bigbinary/neeto-playwright-commons";
 * 
 *    // Convert hexadecimal color code to RGB
 *    const rgbColor = hexToRGB("#ff0000");
 * 
 *    console.log(rgbColor); // Output: 'rgb(255, 0, 0)'
 * 
 *    // Convert another hexadecimal color code to RGB
 *    const anotherRGBColor = hexToRGB("#00ff00");
 * 
 *    console.log(anotherRGBColor); // Output: 'rgb(0, 255, 0)'
 * @endexample
*/
declare const hexToRGB: (hex: string) => string;
declare const filterUtils: {
  /**
   *
   * Opens the filter pane on page.
   *
   * page: An instance of the Playwright Page class representing the web page where the filter pane should be opened.
   *
   * @example 
   *
   *   import { Page } from "@playwright/test";
   *   import { filterUtils } from "@bigbinary/neeto-playwright-commons";
   * 
   *   await filterUtils.openFilterPane(page);
   * @endexample
  */
  openFilterPane: (page: Page) => Promise<void>;
  clearFiltersFromActionBlock: (page: Page) => Promise<void>;
};
/**
 *
 * Function to get the image path and name from the image in a given path.
 *
 * @example 
 *
 *   import { getImagePathAndName } from "@bigbinary/neeto-playwright-commons";
 * 
 *   const { imagePath, imageName } = getImagePathAndName("../assets/images/image.png");
 * @endexample
*/
declare const getImagePathAndName: (localImagePath: string) => {
  imagePath: string;
  imageName: string;
};
interface CurrentsOverrides {
  projectId: string;
}
interface PlaydashOverrides {
  projectKey: string;
}
interface Overrides {
  globalOverrides?: Record<string, unknown>;
  useOverrides?: Record<string, unknown>;
  useCustomProjects?: boolean;
  projectOverrides?: Record<string, unknown>[];
  currentsOverrides: CurrentsOverrides & Record<string, unknown>;
  playdashStagingOverrides?: PlaydashOverrides & Record<string, unknown>;
  playdashProductionOverrides?: PlaydashOverrides & Record<string, unknown>;
}
/**
 *
 * This function returns the default playwright configuration object. It can be
 *
 * used to extend the default playwright configuration object in the host project.
 *
 * @example 
 *
 *   import { definePlaywrightConfig } from "@bigbinary/neeto-playwright-commons";
 * 
 *   export default definePlaywrightConfig({
 *     currentsOverrides: { projectId: "******" },
 *   });
 * @endexample
*/
declare const definePlaywrightConfig: (overrides: Overrides) => _playwright_test.PlaywrightTestConfig<{}, {}>;
export { API_ROUTES, ATTACHMENT_DELETION_TOASTR_MESSAGE, BASE_URL, CHANGELOG_WIDGET_SELECTORS, CHAT_WIDGET_SELECTORS, CHAT_WIDGET_TEXTS, COMMON_SELECTORS, CREDENTIALS, CustomCommands, type CustomFixture, DESCRIPTION_EDITOR_TEXTS, EMBED_SELECTORS, EMOJI_PICKER_LABEL, ENVIRONMENT, EXPANDED_FONT_SIZE, EditorPage, EmbedBase, FONT_SIZE_SELECTORS, GLOBAL_TRANSLATIONS_PATTERN, HELP_CENTER_SELECTORS, HelpAndProfilePage, INTEGRATIONS_TEXTS, INTEGRATION_SELECTORS, IS_STAGING_ENV, ImageUploader, IntegrationBase, KEYBOARD_SHORTCUTS_SELECTORS, LIST_MODIFIER_SELECTORS, LIST_MODIFIER_TAGS, LOGIN_SELECTORS, MEMBER_FORM_SELECTORS, MEMBER_SELECTORS, MEMBER_TEXTS, MERGE_TAGS_SELECTORS, MailosaurUtils, NEETO_AUTH_BASE_URL, NEETO_EDITOR_SELECTORS, NEETO_FILTERS_SELECTORS, NEETO_IMAGE_UPLOADER_SELECTORS, NEETO_ROUTES, NEETO_TEXT_MODIFIER_SELECTORS, OTP_EMAIL_PATTERN, OrganizationPage, PROFILE_SECTION_SELECTORS, PROJECT_TRANSLATIONS_PATH, ROLES_SELECTORS, ROUTES, SIGNUP_SELECTORS, SLACK_DATA_QA_SELECTORS, SLACK_DEFAULT_CHANNEL, SLACK_SELECTORS, SLACK_WEB_TEXTS, STORAGE_STATE, SidebarSection, SlackPage, TAGS_SELECTORS, TEXT_MODIFIER_ROLES, TEXT_MODIFIER_SELECTORS, TEXT_MODIFIER_TAGS, THIRD_PARTY_ROUTES, TOASTR_MESSAGES, TagsPage, TeamMembers, USER_AGENTS, WebhooksPage, ZAPIER_LIMIT_EXHAUSTED_MESSAGE, ZAPIER_SELECTORS, ZAPIER_TEST_EMAIL, ZAPIER_WEB_TEXTS, ZapierPage, basicHTMLContent, clearCredentials, commands, cpuThrottlingUsingCDP, decodeQRCodeFromFile, definePlaywrightConfig, executeWithThrottledResources, extractSubdomainFromError, filterUtils, generateRandomBypassEmail, generateStagingData, getByDataQA, getGlobalUserState, getImagePathAndName, getListCount, headerUtils, hexToRGB, hyphenize, i18nFixture, initializeCredentials, initializeTotp, joinHyphenCase, joinString, login, loginWithoutSSO, memberUtils, networkConditions, networkThrottlingUsingCDP, readFileSyncIfExists, removeCredentialFile, shouldSkipSetupAndTeardown, skipTest, squish, _default as stealthTest, tableUtils, toCamelCase, updateCredentials, writeDataToFile };